from abaqusConstants import *
from .InteractionState import InteractionState


class XFEMCrackGrowthState(InteractionState):
    """The XFEMCrackGrowthState object stores the propagating data of an XFEMCrackGrowth object
    in a step. One instance of this object is created internally by the XFEMCrackGrowth
    object for each step. The instance is also deleted internally by the XFEMCrackGrowth
    object.
    The XFEMCrackGrowthState object has no constructor or methods.
    The XFEMCrackGrowthState object is derived from the InteractionState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].steps[name].interactionStates[name]

        The corresponding analysis keywords are:

        - ENRICHMENT ACTIVATION
    """

    #: A Boolean specifying whether the crack is allowed to grow (propagate) during this
    #: analysis step. The default value is ON.
    allowGrowth: Boolean = ON

    #: A SymbolicConstant specifying the propagation state of the **allowGrowth** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    allowGrowthState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None



from abaqusConstants import *
from .BoundaryConditionState import BoundaryConditionState


class AccelerationBCState(BoundaryConditionState):
    """The AccelerationBCState object stores the propagating data of an acceleration boundary
    condition in a step. One instance of this object is created internally by the
    AccelerationBC object for each step. The instance is also deleted internally by the
    AccelerationBC object.
    The AccelerationBCState object has no constructor or methods.
    The AccelerationBCState object is derived from the BoundaryConditionState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].steps[name].boundaryConditionStates[name]

        The corresponding analysis keywords are:

        - BOUNDARY
    """

    #: A Float specifying the acceleration component in the 1-direction.
    a1: float = None

    #: A Float specifying the acceleration component in the 2-direction.
    a2: float = None

    #: A Float specifying the acceleration component in the 3-direction.
    a3: float = None

    #: A Float specifying the rotational acceleration component about the 1-direction.
    ar1: float = None

    #: A Float specifying the rotational acceleration component about the 2-direction.
    ar2: float = None

    #: A Float specifying the rotational acceleration component about the 3-direction.
    ar3: float = None

    #: A SymbolicConstant specifying the propagation state of the acceleration component in the
    #: 1-direction. Possible values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    a1State: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the acceleration component in the
    #: 2-direction. Possible values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    a2State: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the acceleration component in the
    #: 3-direction. Possible values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    a3State: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the rotational acceleration
    #: component about the 1-direction. Possible values are UNSET, SET, UNCHANGED, FREED, and
    #: MODIFIED.
    ar1State: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the rotational acceleration
    #: component about the 2-direction. Possible values are UNSET, SET, UNCHANGED, FREED, and
    #: MODIFIED.
    ar2State: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the rotational acceleration
    #: component about the 3-direction. Possible values are UNSET, SET, UNCHANGED, FREED, and
    #: MODIFIED.
    ar3State: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the amplitude reference. Possible
    #: values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the BoundaryConditionState object. Possible values are:
    #: NOT_YET_ACTIVE
    #: CREATED
    #: PROPAGATED
    #: MODIFIED
    #: DEACTIVATED
    #: NO_LONGER_ACTIVE
    #: TYPE_NOT_APPLICABLE
    #: INSTANCE_NOT_APPLICABLE
    #: PROPAGATED_FROM_BASE_STATE
    #: MODIFIED_FROM_BASE_STATE
    #: DEACTIVATED_FROM_BASE_STATE
    #: BUILT_INTO_MODES
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the
    #: boundary condition has no amplitude reference.
    amplitude: str = ""



from abaqusConstants import *


class OptionArg:
    """The OptionArg object is used to store values and attributes as a temporary object to be
    associated with a viewCutOptions object. The OptionArg object has only a constructor
    command.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.defaultOdbDisplay.viewCutOptions.aboveOptions
            session.defaultOdbDisplay.viewCutOptions.belowOptions
            session.defaultOdbDisplay.viewCutOptions.onOptions
            session.viewports[name].layers[name].odbDisplay.viewCutOptions.aboveOptions
            session.viewports[name].layers[name].odbDisplay.viewCutOptions.belowOptions
            session.viewports[name].layers[name].odbDisplay.viewCutOptions.onOptions
            session.viewports[name].odbDisplay.viewCutOptions.aboveOptions
            session.viewports[name].odbDisplay.viewCutOptions.belowOptions
            session.viewports[name].odbDisplay.viewCutOptions.onOptions
    """

    #: A SymbolicConstant specifying the render style of the plot. Possible values are
    #: WIREFRAME, FILLED, HIDDEN, and SHADED. The default value is WIREFRAME.
    renderStyle: SymbolicConstant = WIREFRAME

    #: A SymbolicConstant specifying which edges to plot. Possible values are ALL, EXTERIOR,
    #: FEATURE, FREE, and NONE. The default value is FEATURE.NONE can be used only when
    #: **renderStyle** = SHADED.
    visibleEdges: SymbolicConstant = FEATURE

    #: A String specifying the color to be used to plot the edges of the undeformed plot when
    #: **renderStyle** = WIREFRAME or HIDDEN. The default value is "Green".
    edgeColorWireHide: str = ""

    #: A String specifying the color to be used to plot the edges of the undeformed plot when
    #: **renderStyle** = FILLED or SHADED. The default value is "Black".
    edgeColorFillShade: str = ""

    #: A SymbolicConstant specifying the edge line style. Possible values are SOLID, DASHED,
    #: DOTTED, and DOT_DASH. The default value is SOLID.
    edgeLineStyle: SymbolicConstant = SOLID

    #: A SymbolicConstant specifying the edge line thickness. Possible values are VERY_THIN,
    #: THIN, MEDIUM, and THICK. The default value is VERY_THIN.
    edgeLineThickness: SymbolicConstant = VERY_THIN

    #: A Boolean specifying whether to allow color coded items in the output database to
    #: override the edge and fill color settings. The default value is ON.
    colorCodeOverride: Boolean = ON

    #: A String specifying the color to be used to fill elements when **renderStyle** = FILLED or
    #: SHADED. The default value is "Green".
    fillColor: str = ""

    #: A Boolean specifying whether to set translucency. The default value is OFF.
    translucency: Boolean = OFF

    #: A Float specifying the translucency factor when **translucency** = ON. Possible values are
    #: 0.0 ≤≤ **translucencyFactor** ≤≤ 1.0. The default value is 0.3.
    translucencyFactor: float = 0

    def __init__(
        self,
        renderStyle: SymbolicConstant = WIREFRAME,
        visibleEdges: SymbolicConstant = FEATURE,
        edgeColorWireHide: str = "",
        edgeColorFillShade: str = "",
        edgeLineStyle: SymbolicConstant = SOLID,
        edgeLineThickness: SymbolicConstant = VERY_THIN,
        colorCodeOverride: Boolean = ON,
        fillColor: str = "",
        translucency: Boolean = OFF,
        translucencyFactor: float = 0,
    ):
        """This method creates an OptionArg object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                visualization.OptionArg

        Parameters
        ----------
        renderStyle
            A SymbolicConstant specifying the render style of the plot. Possible values are
            WIREFRAME, FILLED, HIDDEN, and SHADED. The default value is WIREFRAME.
        visibleEdges
            A SymbolicConstant specifying which edges to plot. Possible values are ALL, EXTERIOR,
            FEATURE, FREE, and NONE. The default value is FEATURE.NONE can be used only when
            **renderStyle** = SHADED.
        edgeColorWireHide
            A String specifying the color to be used to plot the edges of the undeformed plot when
            **renderStyle** = WIREFRAME or HIDDEN. The default value is "Green".
        edgeColorFillShade
            A String specifying the color to be used to plot the edges of the undeformed plot when
            **renderStyle** = FILLED or SHADED. The default value is "Black".
        edgeLineStyle
            A SymbolicConstant specifying the edge line style. Possible values are SOLID, DASHED,
            DOTTED, and DOT_DASH. The default value is SOLID.
        edgeLineThickness
            A SymbolicConstant specifying the edge line thickness. Possible values are VERY_THIN,
            THIN, MEDIUM, and THICK. The default value is VERY_THIN.
        colorCodeOverride
            A Boolean specifying whether to allow color coded items in the output database to
            override the edge and fill color settings. The default value is ON.
        fillColor
            A String specifying the color to be used to fill elements when **renderStyle** = FILLED or
            SHADED. The default value is "Green".
        translucency
            A Boolean specifying whether to set translucency. The default value is OFF.
        translucencyFactor
            A Float specifying the translucency factor when **translucency** = ON. Possible values are
            0.0 ≤≤ **translucencyFactor** ≤≤ 1.0. The default value is 0.3.

        Returns
        -------
        OptionArg
            An :py:class:`~abaqus.PlotOptions.OptionArg.OptionArg` object.

        Raises
        ------
        RangeError
        """
        pass



from abaqusConstants import *
from .Inertia import Inertia
from ..Region.Region import Region


class HeatCapacitance(Inertia):
    """The HeatCapacitance object defines point heat capacitance on a part or an assembly
    region.
    The HeatCapacitance object is derived from the Inertia object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import part
            mdb.models[name].parts[name].engineeringFeatures.inertias[name]
            import assembly
            mdb.models[name].rootAssembly.engineeringFeatures.inertias[name]

        The table data specify the following:
        
        - Heat capacitance magnitude, ρcVρ⁢c⁢V (density × specific heat × volume).
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - HEATCAP
    """

    #: A Boolean specifying whether the inertia is suppressed or not. The default value is OFF.
    suppressed: Boolean = OFF

    #: A String specifying the repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the heat capacitance is applied.
    region: Region

    #: A sequence of sequences of Floats specifying heat capacitance properties. The items in
    #: the table data are described below.
    table: tuple

    #: A Boolean specifying whether the data depend on temperature. The default value is OFF.
    temperatureDependency: Boolean = OFF

    #: An Int specifying the number of field variable dependencies. The default value is 0.
    dependencies: int = 0

    def __init__(
        self,
        name: str,
        region: Region,
        table: tuple,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a HeatCapacitance object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].parts[name].engineeringFeatures.HeatCapacitance
                mdb.models[name].rootAssembly.engineeringFeatures.HeatCapacitance

        Parameters
        ----------
        name
            A String specifying the repository key.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the heat capacitance is applied.
        table
            A sequence of sequences of Floats specifying heat capacitance properties. The items in
            the table data are described below.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        HeatCapacitance
            A :py:class:`~abaqus.EngineeringFeature.HeatCapacitance.HeatCapacitance` object.
        """
        super().__init__()
        pass

    def setValues(self, temperatureDependency: Boolean = OFF, dependencies: int = 0):
        """This method modifies the HeatCapacitance object.

        Parameters
        ----------
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        """
        pass



from abaqusConstants import *


class InitializationAssignment:
    """The InitializationAssignment object stores the contact initialization assignment
    definition for domain pairs in a ContactStd or ContactExp object. The
    InitializationAssignment object has no constructor or members.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactions[name].initializationAssignments

        The corresponding analysis keywords are:

        - CONTACT INITIALIZATION ASSIGNMENT
    """

    def changeValuesInStep(self, stepName: str, index: int, value: str):
        """This method allows modification of contact initialization assignments to domain pairs
        already defined in a given step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the contact initialization assignments
            are to be modified.
        index
            An Int specifying the position of the contact initialization assignment whose value is
            to be modified.
        value
            A String specifying the value of the contact initialization to be assigned to the domain
            pair whose index is referenced.
        """
        pass

    def appendInStep(self, stepName: str, assignments: SymbolicConstant):
        """This method allows addition of contact initialization assignments to new domain pairs in
        a given step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which new contact initialization assignments
            are to be defined.
        assignments
            A sequence of tuples specifying the initializations assigned to each surface pair. Each
            tuple contains four entries (fourth entry is for Abaqus/Explicit and is optional):
            - A region object or the SymbolicConstant GLOBAL (for Abaqus/Standard only).
            - A region object or the SymbolicConstant SELF (for Abaqus/Standard only).
            - A String specifying a StdInitialization or ExpInitializationobject associated with this pair of regions.
            - A String specifying a slave surface type. This entry is applicable only if the ExpInitialization object is defined with **overclosureType** = CLEARANCE and **adjustNodalCoords** = True.
        """
        pass

    def delete(self, indices: tuple):
        """The delete method allows you to delete existing contact initialization assignments from
        a ContactStd or ContactExp object.

        Parameters
        ----------
        indices
            A sequence of Ints specifying the index of each contact initialization assignment to
            delete.
        """
        pass



from abaqusConstants import *
from .Constraint import Constraint
from ..Assembly.PartInstance import PartInstance
from ..BasicGeometry.ModelDotArray import ModelDotArray


class DisplayBody(Constraint):
    """The DisplayBody object defines a constraint such that the specified instance is used for
    display only and does not take part in the analysis. However it will still be visible
    during postprocessing and its position at any frame will be defined by the translation
    and rotation of the specified control points.
    The DisplayBody object is derived from the ConstrainedSketchConstraint object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].constraints[name]

        The corresponding analysis keywords are:

        - DISPLAY BODY
    """

    #: A Boolean specifying whether the constraint is suppressed or not. The default value is
    #: OFF.
    suppressed: Boolean = OFF

    #: A String specifying the constraint repository key.
    name: str

    #: A :py:class:`~abaqus.Assembly.PartInstance.PartInstance` object specifying the part instance that is to be used for display only.
    instance: PartInstance

    #: A :py:class:`~abaqus.BasicGeometry.ModelDotArray.ModelDotArray` object specifying the motion of the PartInstance. The control points may
    #: be ConstrainedSketchVertex, ReferencePoint, or MeshNode objects. Their motion will control the motion of
    #: the PartInstance. If this argument is set to an empty sequence, the PartInstance will
    #: remain fixed in space during the analysis. The sequence can have either one object or
    #: three objects.
    controlPoints: ModelDotArray

    def __init__(self, name: str, instance: PartInstance, controlPoints: ModelDotArray):
        """This method creates a DisplayBody object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].DisplayBody

        Parameters
        ----------
        name
            A String specifying the constraint repository key.
        instance
            A :py:class:`~abaqus.Assembly.PartInstance.PartInstance` object specifying the part instance that is to be used for display only.
        controlPoints
            A :py:class:`~abaqus.BasicGeometry.ModelDotArray.ModelDotArray` object specifying the motion of the PartInstance. The control points may
            be ConstrainedSketchVertex, ReferencePoint, or MeshNode objects. Their motion will control the motion of
            the PartInstance. If this argument is set to an empty sequence, the PartInstance will
            remain fixed in space during the analysis. The sequence can have either one object or
            three objects.

        Returns
        -------
        DisplayBody
            A :py:class:`~abaqus.Constraint.DisplayBody.DisplayBody` object.
        """
        super().__init__()
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the DisplayBody object."""
        pass



from abaqusConstants import *


class DeformationPlasticity:
    r"""The DeformationPlasticity object specifies the deformation plasticity model.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].deformationPlasticity
            import odbMaterial
            session.odbs[name].materials[name].deformationPlasticity

        The table data for this object are:

        - Young's modulus, :math:`E`.
        - Poisson's ratio, :math:`\nu`.
        - Yield stress, :math:`\sigma^{0}`
        - Exponent, :math:`n`.
        - Yield offset, :math:`\alpha`.
        - Temperature, if the data depend on temperature.

        The corresponding analysis keywords are:

        - DEFORMATION PLASTICITY
    """

    def __init__(self, table: tuple, temperatureDependency: Boolean = OFF):
        """This method creates a DeformationPlasticity object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].DeformationPlasticity
                session.odbs[name].materials[name].DeformationPlasticity

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.

        Returns
        -------
        DeformationPlasticity
            A :py:class:`~abaqus.Material.Plastic.Metal.Deformation.DeformationPlasticity.DeformationPlasticity` object.

        Raises
        ------
        RangeError
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the DeformationPlasticity object.

        Raises
        ------
        RangeError
        """
        pass



class StructuralDampingByFrequencyComponent:
    """A :py:class:`~abaqus.StepMiscellaneous.StructuralDampingByFrequencyComponent.StructuralDampingByFrequencyComponent` object is used to define structural damping over
    a range of frequencies.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name].structuralDampingByFrequency.components[i]
    """

    #: A Float specifying the frequency value in cycles/time.
    frequency: float = None

    #: A Float specifying the damping factor, s.
    factor: float = None



from ..Calibration.Behavior import Behavior
from ..Calibration.DataSet import DataSet


class Calibration:
    """A :py:class:`~abaqus.BoundaryCondition.Calibration.Calibration` object is the object used to specify a material calibration. The
    Calibration object stores the data that is used for specifying materials from test data.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import calibration
            mdb.models[name].calibrations[name]
    """

    #: A :py:class:`~abaqus.Calibration.DataSet.DataSet` object.
    dataSets: DataSet = None

    #: A :py:class:`~abaqus.Calibration.Behavior.Behavior` object.
    behaviors: Behavior = None

    #: A String specifying the name of the new calibration.
    name: str

    def __init__(self, name: str):
        """This method creates a Calibration object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].Calibration

        Parameters
        ----------
        name
            A String specifying the name of the new calibration.

        Returns
        -------
        Calibration
            A :py:class:`~abaqus.BoundaryCondition.Calibration.Calibration` object.
        """
        pass



from abaqusConstants import *
from ..Session.SessionBase import SessionBase


class XYSessionBase(SessionBase):
    """The following commands operate on Session objects. For more information about the
    Session object, see Session object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
    """

    def linearizeStress(
        self,
        name: str,
        path: str,
        startPoint: str,
        endPoint: str,
        modelShape: SymbolicConstant,
        components: tuple,
        xyMembraneComps: tuple,
        xyBendingComps: tuple,
        invariantBendingComps: tuple = (),
        intervals: int = 40,
        radiusOfCurvature: float = None,
        oopRadiusOfCurvature: float = None,
        curvatureCorrection: Boolean = OFF,
        curvatureCsys: str = "",
        useCurvatureCsysForOrient: Boolean = OFF,
        saveXy: Boolean = OFF,
        writeReport: Boolean = OFF,
        reportFile: str = "",
        appendToFile: Boolean = OFF,
        saveToPath: Boolean = OFF,
    ):
        """This method is used to perform stress linearization along a defined stress line.

        Parameters
        ----------
        name
            A String specifying the name of the stress line.
        path
            APath object specifying the end points of the stress line.Note:You must provide either
            the **path** argument or the **startPoint** and **endPoint** arguments.
        startPoint
            A String specifying a part instance and a node belonging to that part instance, or a
            sequence of three Floats specifying the coordinates of a point.
        endPoint
            A String specifying a part instance and a node belonging to that part instance, or a
            sequence of three Floats specifying the coordinates of a point.
        modelShape
            A SymbolicConstant specifying the model shape to be used for obtaining coordinates of
            the intermediate points along the stress line. Possible values are UNDEFORMED and
            DEFORMED. When DEFORMED is selected, the deformation scale factor is always set to a
            uniform value of 1.0.
        components
            A sequence of Strings specifying the linearized stress components to be displayed in the
            xyPlot object. Possible values are "S11", "S22", "S33", "S12", "S23", and "S13".Note:You
            must provide at least one of the **components** , **xyMembraneComps** , and **xyBendingComps**
            arguments.
        xyMembraneComps
            A sequence of Strings specifying the linearized stress membrane components to be
            displayed in the xyPlot object. Possible values are "S11", "S22", "S33", "S12", "S23",
            and "S13".
        xyBendingComps
            A sequence of Strings specifying the linearized stress bending components to be
            displayed in the xyPlot object. Possible values are "S11", "S22", "S33", "S12", "S23",
            and "S13".
        invariantBendingComps
            A sequence of Strings specifying the linearized stress bending components to be included
            in the computation of the linearized stress invariants. Possible values are "S11",
            "S22", "S33", "S12", "S23", and "S13". The default value of the sequence includes all
            the possible values.
        intervals
            An Int specifying the number of equally-spaced intervals into which the stress line is
            to be divided. The default value is 40.
        radiusOfCurvature
            A Float specifying the in-plane radius of curvature of the center section along the
            stress line for axi-symmetric models. The default value is ∞∞.
        oopRadiusOfCurvature
            A Float specifying the out-of-plane radius of curvature of the center section along the
            Stress Line for axi-symmetric models. The default value forces Abaqus to compute the
            radius of curvature.
        curvatureCorrection
            A Boolean specifying whether the out-of-plane curvature correction should be applied for
            non-axisymmetric models when performing linearized stress computations. Curvature
            correction is always applied for axisymmetric models. The default value is OFF.
        curvatureCsys
            A String specifying the name of the user-defined local coordinate system to be used for
            computing the out-of-plane radius of curvature for non-axisymmetric models when
            **curvatureCorrection** =ON . The default value uses the global coordinate system to
            compute the out-of-plane radius of curvature.
        useCurvatureCsysForOrient
            A Boolean specifying whether to use the user-defined local coordinate system to compute
            the local stress line orientation for non-axisymmetric models when **curvatureCorrection**
            =ON and **curvatureCsys** is specified. The default value is OFF.
        saveXy
            A Boolean specifying whether to save the xyData objects created during the stress
            linearization operation to the session. The default value is OFF .
        writeReport
            A Boolean specifying whether to write the output from the stress linearization operation
            to a text file. The default value is ON .
        reportFile
            A String specifying the report file name. The default value is “linearStress.rpt”.
        appendToFile
            A Boolean specifying whether to append output from the stress linearization to the text
            file specified by the **reportFile** argument. The default value is ON .
        saveToPath
            A Boolean specifying whether to create a Path object containing all the points used when
            performing the linearized stress computation. The default value is OFF . When this
            argument is set to ON , a Path object is created with the same name as that of the
            stress line and placed in the Path repository.

        Returns
        -------
        list[XYData]
            A list of xyData objects.

        Raises
        ------
        TextError
            The stress line passes through incompatible part instances. Results cannot be
            extracted.
        TextError
            Specified variables cannot be used for extracting results along the stress line.
        TextError
            Results for all the points along the stress line were not found. Selected end points
            and all intermediate sample points must lie within the current display group, and within
            solid continuum elements. Due to tolerance limitations, intermediate points lying on
            display group boundaries may fail to meet this criterion. Choose new end points, adjust
            the number of intervals along the line, or modify the current display group to obtain
            the stress linearization plot.
        """
        pass

    def setPathTolerance(self, tolerance: str = 0):
        """This method is used to set the **tolerance** to be used when creating XYData objects by
        extracting results along Path objects. This command should be exercised with caution
        since setting a value too low or too high may result in getting no results or
        unpredictable results.

        Parameters
        ----------
        tolerance
            A Double specifying the tolerance. The default value is 0.00001.

        Returns
        -------
        None .
        """
        pass

    def getPathTolerance(self):
        """This method is used to get the **tolerance** used when creating XYData objects by
        extracting results along Path objects.

        Returns
        -------
        float
            A Double specifying the tolerance.
        """
        pass

    def setLimitForXYDataPlots(self, limit: int = None):
        """This method is used to set the **limit** for number of XY data objects while creating
        XYData from field output.

        Parameters
        ----------
        limit
            None or an Int specifying the limit for number of XY data objects. The default value is
            no limit

        Returns
        -------
        None .
        """
        pass

    def getLimitForXYDataPlots(self):
        """This method is used to get the **limit** for number of XY data objects while creating
        XYData from field output.

        Returns
        -------
        Int specifying the limit for number of XY data objects.
        """
        pass



from abaqusConstants import *


class PolarityAssignments:
    """The PolarityAssignments object stores the polarity assignment definition for surfaces in
    ContactExp objects. The PolarityAssignments object has no constructor or members.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactions[name].polarityAssignments

        The corresponding analysis keywords are:

        - CONTACT FORMULATION
    """

    def changeValuesInStep(self, stepName: str, index: int, value: SymbolicConstant):
        """This method allows you to modify polarity assignments already defined on surface pairs
        in a given step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the master-slave assignments are to
            be modified.
        index
            An Int specifying the position of the polarity assignment whose value is to be modified.
        value
            A SymbolicConstant specifying the value of the polarity to be assigned to the surface
            whose index is referenced. Possible values are SPOS, SNEG, and TWO_SIDED.
        """
        pass

    def appendInStep(self, stepName: str, assignments: SymbolicConstant):
        """This method allows you to add polarity assignments to new surface pairs in a given step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the polarity assignments are to be
            defined.
        assignments
            A sequence of tuples specifying the polarity assignments. Each tuple contains two
            entries:
            - A region object or the SymbolicConstant GLOBAL specifying the surface to which the
              polarity attribute is assigned.
            - A SymbolicConstant specifying the overriding polarity value to be used for the first
              surface. Possible values of the SymbolicConstant are SPOS, SNEG, and TWO_SIDED.
        """
        pass

    def delete(self, indices: tuple):
        """The delete method allows you to delete existing polarity assignments.

        Parameters
        ----------
        indices
            A sequence of Ints specifying the index of each polarity assignment to delete.
        """
        pass



from abaqusConstants import *


class KeywordBlock:
    """The KeywordBlock object contains a representation of its model in the Abaqus input file
    format. You may edit the contents of the KeywordBlock to add solver functionality that
    is not supported by Abaqus/CAE. As a general rule, edits to the KeywordBlock object
    should be made as the last step prior to writing the actual Abaqus input file, thus
    avoiding possible conflicts with changes made using other MDB commands. The KeywordBlock
    object has no constructor. A :py:class:`~abaqus.Model.KeywordBlock.KeywordBlock` object is created when you create a model
    object. A model object contains only one KeywordBlock object.

    Notes
    -----
    This object can be accessed by:
        mdb.models[name].keywordBlock
    """

    #: A Boolean specifying whether the Keywords Editor has been used to change the model.
    edited: Boolean = OFF

    #: A Float specifying the value of the counter associated with the Mdb object at the most
    #: recent synchronization.
    lastSynchCount: float = None

    #: A tuple of Strings specifying a sequence of Strings that is identical to the information
    #: written to the Abaqus input file. Each String in the sequence represents an Abaqus input
    #: file keyword along with the parameters and data lines associated with the keyword. A
    #: String can also be a comment in the input file. You initialize this data member by
    #: calling synchVersions. After you initialize the data member, you use calls to replace
    #: and insert to record your edits in the correct location. If the last call to
    #: synchVersions used the argument **storeNodesAndElements** = False, the entry for the
    #: keywords NODE and ELEMENT will contain only the keyword and its parameters, not the data
    #: lines.
    sieBlocks: tuple = ()

    def setValues(self, edited: Boolean = OFF):
        """This method modifies the KeywordBlock object.

        Parameters
        ----------
        edited
            A Boolean specifying whether this objects **sieBlocks** member has been edited. Setting
            edited=False will set the **sieBlocks** member to an empty tuple, thereby discarding all
            previous edits.
        """
        pass

    def insert(self, position: int, text: str):
        """This method inserts a String at a specified position in the **sieBlocks** member.

        Parameters
        ----------
        position
            An Int specifying the position in the **sieBlocks** member after which the new string will
            be inserted.
        text
            A String specifying the text to be inserted. The text represents an Abaqus input file
            keyword and its associated data

        Raises
        ------
        IndexError
        """
        pass

    def replace(self, position: int, text: str):
        """This method replaces a String at a specified position in the **sieBlocks** member.

        Parameters
        ----------
        position
            An Int specifying the position of the String to be replaced in the **sieBlocks** member.
        text
            A String specifying the text to be replaced. The text represents an Abaqus input file
            keyword and its associated data.

        Raises
        ------
        IndexError
        """
        pass

    def synchVersions(self, storeNodesAndElements: Boolean):
        """This method synchronizes, or merges, the edits made in this object with those made in
        the model using other scripting commands or the user interface. The synchVersions method
        updates the **sieBlocks** member. The **sieBlocks** member is empty prior to the first call
        to synchVersions. As a side effect, synchVersions sets **lastSynchCount** to the current
        value of the counter associated with the Mdb object, which is used to determine if
        synchronization is necessary.

        Parameters
        ----------
        storeNodesAndElements
            A Boolean specifying whether the nodal coordinates and element connectivities (i.e. the
            data lines for the *NODE and *ELEMENT keyword blocks) are to be stored in the
            **sieBlocks** member. All other keywords and their data lines are always stored. The
            default value is True. If **storeNodesAndElements** is True, the size of the keywordBlock
            data will be similar to that of the input file. Since the KeywordBlock is stored in the
            Abaqus/CAE database, this will result in a larger database. It will also result in a
            slower execution of the synchVersions command. If **storeNodesAndElements** is False, the
            data lines are not stored in **sieBlocks**. Consequently, only set
            **storeNodesAndElements** = True if you wish to make changes to the *NODE or *ELEMENT data
            lines themselves. If your task is limited to reading nodal coordinates and element
            connectivities (i.e. not editing this information) then it is generally better to access
            this information from other parts of the Mdb.

        Raises
        ------
        IndexError
        """
        pass



from abaqusConstants import *


class ViewerOptions:
    """The ViewerOptions object specifies options to set the result caching parameters. The
    ViewerOptions object has no constructor. Abaqus creates the **viewerOptions** member when
    a session is started.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.viewerOptions
    """

    def setValues(
        self,
        primaryVariableCaching: Boolean = ON,
        deformedVariableCaching: Boolean = ON,
        cutVariableCaching: Boolean = ON,
        odbUpdateChecking: Boolean = ON,
        odbUpdateCheckInterval: int = 0,
    ):
        """This method modifies the ViewerOptions object.

        Parameters
        ----------
        primaryVariableCaching
            A Boolean specifying whether results are currently cached. Caching improves the
            performance of subsequent access. The default value is ON.
        deformedVariableCaching
            A Boolean specifying whether deformation vectors are currently cached. Caching improves
            the performance of subsequent access. The default value is ON.
        cutVariableCaching
            A Boolean specifying whether the values used for displaying cut models are currently
            cached. Caching improves the performance of subsequent access. The default value is ON.
        odbUpdateChecking
            A Boolean specifying whether the current .odb file should be checked for updates.
            Setting **odbUpdateChecking** to OFF can improve Viewer performance when accessing data
            from a remote file. The default value is ON.
        odbUpdateCheckInterval
            An Int specifying the minimum time between status checks (in seconds). The default value
            is 0.
        """
        pass



import typing

from abaqusConstants import *
from .DesignResponse import DesignResponse
from .GeometricRestriction import GeometricRestriction
from .ObjectiveFunction import ObjectiveFunction
from .OptimizationConstraint import OptimizationConstraint
from .OptimizationTask import OptimizationTask
from .StopCondition import StopCondition


class TopologyTask(OptimizationTask):
    """The TopologyTask object defines a topology task.
    The TopologyTask object is derived from the OptimizationTask object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import optimization
            mdb.models[name].optimizationTasks[name]
    """

    #: A repository of DesignResponse objects.
    designResponses: dict[str, DesignResponse] = dict[str, DesignResponse]()

    #: A repository of ObjectiveFunction objects.
    objectiveFunctions: dict[str, ObjectiveFunction] = dict[str, ObjectiveFunction]()

    #: A repository of OptimizationConstraint objects.
    optimizationConstraints: dict[str, OptimizationConstraint] = dict[
        str, OptimizationConstraint
    ]()

    #: A repository of GeometricRestriction objects.
    geometricRestrictions: dict[str, GeometricRestriction] = dict[
        str, GeometricRestriction
    ]()

    #: A repository of StopCondition objects.
    stopConditions: dict[str, StopCondition] = dict[str, StopCondition]()

    #: A String specifying the optimization task repository key.
    name: str

    #: A Boolean specifying whether to use Abaqus to compute the design responses and their
    #: sensitivities. The default value is False.
    abaqusSensitivities: Boolean = False

    #: A SymbolicConstant specifying the optimization task algorithm. Possible values are
    #: GENERAL_OPTIMIZATION and CONDITION_BASED_OPTIMIZATION. The default value is
    #: GENERAL_OPTIMIZATION.
    algorithm: SymbolicConstant = GENERAL_OPTIMIZATION

    #: A Float specifying the maximum density change per design cycle. The default value is
    #: 0.25.
    densityMoveLimit: float = 0

    #: A SymbolicConstant specifying the strategy for how the densities are updated in the
    #: method of moving asymptotes. Possible values are NORMAL, CONSERVATIVE, and AGGRESSIVE.
    #: The default value is NORMAL.
    densityUpdateStrategy: SymbolicConstant = NORMAL

    #: A Float specifying the stop criteria based upon the change in element densities. The
    #: default value is 0.5×10-2.
    elementDensityDeltaStopCriteria: float = 0

    #: None or a Float specifying the mesh filter radius for mesh independence and minimum
    #: size. The default value is None.
    filterRadius: float = None

    #: A Float specifying the volume that can be removed immediately in the first design cycle.
    #: The default value is 5.0.
    firstCycleDeletedVolume: float = 5

    #: A SymbolicConstant specifying the method of quantifying volume that can be removed
    #: immediately in the first design cycle. Possible values are OFF, PERCENTAGE, and
    #: ABSOLUTE. The default value is OFF.
    firstCycleDeletedVolumeTechnique: SymbolicConstant = OFF

    #: A Boolean specifying whether to exclude elements with boundary conditions from the
    #: optimization. The default value is OFF.
    freezeBoundaryConditionRegions: Boolean = OFF

    #: A Boolean specifying whether to exclude elements with loads and elements with loaded
    #: nodes from the optimization. The default value is ON.
    freezeLoadRegions: Boolean = ON

    #: A Float specifying the weighting factor for frequency spectrum peaks. The default value
    #: is 6.0.
    frequencySpectrumWeight: float = 6

    #: A SymbolicConstant specifying the Optimization product default or a float specifying the
    #: initial density. The default value is DEFAULT.
    initialDensity: SymbolicConstant = DEFAULT

    #: A Float specifying the penalty factor for the material interpolation technique. The
    #: default value is 3.0.
    materialInterpolationPenalty: float = 3

    #: A SymbolicConstant specifying the material interpolation technique: optimization product
    #: default, solid isotropic material with penalization, or rational approximation of
    #: material properties. Possible values are DEFAULT, SIMP, and RAMP. The default value is
    #: DEFAULT.
    materialInterpolationTechnique: SymbolicConstant = DEFAULT

    #: A Float specifying the maximum density in the density update. The default value is 1.0.
    maxDensity: float = 1

    #: A Float specifying the minimum density in the density update. The default value is 10-3.
    minDensity: float = None

    #: The SymbolicConstant MODEL or a Region object specifying the region to use for mode
    #: tracking. The default value is MODEL.
    modeTrackingRegion: SymbolicConstant = MODEL

    #: An Int specifying the number of design cycles permitted when **stepSize** is DYNAMIC. The
    #: default value is 15.
    numDesignCycles: int = 15

    #: An Int specifying the number of stop criteria. The default value is 2.
    numFulfilledStopCriteria: int = 2

    #: An Int specifying the number of modes included in mode tracking. The default value is 5.
    numTrackedModes: int = 5

    #: A Float specifying the stop criteria based on the change in objective function. The
    #: default value is 10-3.
    objectiveFunctionDeltaStopCriteria: float = None

    #: The SymbolicConstant MODEL or a Region object specifying the region to which the
    #: optimization task is applied. The default value is MODEL.
    region: SymbolicConstant = MODEL

    #: A SymbolicConstant specifying the method used when **softDeletionRegion** is specified.
    #: The STANDARD method avoids creating disconnected regions. The AGGRESSIVE method only
    #: considers the **softDeletionThreshold**. The MAX_SHEAR_STRAIN, MAX_ELASTOPLASTIC_STRAIN
    #: and VOLUME_COMPRESSION methods do not need the **softDeletionRadius**. Possible values are
    #: STANDARD, AGGRESSIVE, MAX_SHEAR_STRAIN, MIN_PRINCIPAL_STRAIN, MAX_ELASTOPLASTIC_STRAIN
    #: and VOLUME_COMPRESSION. The default value is STANDARD.
    softDeletionMethod: SymbolicConstant = STANDARD

    #: A Float specifying the radius to use when considering neighboring soft elements to
    #: delete. The default value is 0.0.
    softDeletionRadius: float = 0

    #: None or a Region object specifying the region in which the soft elements should be
    #: deleted during optimization. The default value is None.
    softDeletionRegion: str = None

    #: A Float specifying the relative material density value used to identify soft elements.
    #: Those with values below the threshold are considered for removal. For STANDARD and
    #: AGGRESSIVE methods positive values are accepted and the default value is 0.05. For
    #: MAX_SHEAR_STRAIN and MAX_ELASTOPLASTIC_STRAIN methods positive values are accepted
    #: whereas for MIN_PRINCIPAL_STRAIN and VOLUME_COMPRESSION methods negative values are
    #: accepted.
    softDeletionThreshold: float = None

    #: A SymbolicConstant specifying the size of the increment for volume modification.
    #: Possible values are DYNAMIC, VERY_SMALL, SMALL, MODERATE, MEDIUM, and LARGE. The default
    #: value is MEDIUM.
    stepSize: SymbolicConstant = MEDIUM

    #: The SymbolicConstant AVERAGE_EDGE_LENGTH or a Float specifying the stiffness mass
    #: damping for the task region. The default value is AVERAGE_EDGE_LENGTH.
    stiffnessMassDamping: typing.Union[SymbolicConstant, float] = AVERAGE_EDGE_LENGTH

    #: An Int specifying the first design cycle used to evaluate convergence criteria. The
    #: default value is 4.
    stopCriteriaDesignCycle: int = 4

    #: None or a Float specifying the structural mass damping for the task region. The default
    #: value is None.
    structuralMassDamping: float = None

    #: None or a Float specifying the viscous mass damping for the task region. The default
    #: value is None.
    viscousMassDamping: float = None

    #: None or a Float specifying the viscous stiffness damping for the task region. The
    #: default value is None.
    viscousStiffnessDamping: float = None

    def __init__(
        self,
        name: str,
        abaqusSensitivities: Boolean = False,
        algorithm: SymbolicConstant = GENERAL_OPTIMIZATION,
        densityMoveLimit: float = 0,
        densityUpdateStrategy: SymbolicConstant = NORMAL,
        elementDensityDeltaStopCriteria: float = 0,
        filterRadius: float = None,
        firstCycleDeletedVolume: float = 5,
        firstCycleDeletedVolumeTechnique: SymbolicConstant = OFF,
        freezeBoundaryConditionRegions: Boolean = OFF,
        freezeLoadRegions: Boolean = ON,
        frequencySpectrumWeight: float = 6,
        initialDensity: SymbolicConstant = DEFAULT,
        materialInterpolationPenalty: float = 3,
        materialInterpolationTechnique: SymbolicConstant = DEFAULT,
        maxDensity: float = 1,
        minDensity: float = None,
        modeTrackingRegion: SymbolicConstant = MODEL,
        numDesignCycles: int = 15,
        numFulfilledStopCriteria: int = 2,
        numTrackedModes: int = 5,
        objectiveFunctionDeltaStopCriteria: float = None,
        region: SymbolicConstant = MODEL,
        softDeletionMethod: SymbolicConstant = STANDARD,
        softDeletionRadius: float = 0,
        softDeletionRegion: str = None,
        softDeletionThreshold: float = None,
        stepSize: SymbolicConstant = MEDIUM,
        stiffnessMassDamping: typing.Union[
            SymbolicConstant, float
        ] = AVERAGE_EDGE_LENGTH,
        stopCriteriaDesignCycle: int = 4,
        structuralMassDamping: float = None,
        viscousMassDamping: float = None,
        viscousStiffnessDamping: float = None,
    ):
        """This method creates a TopologyTask object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].TopologyTask

        Parameters
        ----------
        name
            A String specifying the optimization task repository key.
        abaqusSensitivities
            A Boolean specifying whether to use Abaqus to compute the design responses and their
            sensitivities. The default value is False.
        algorithm
            A SymbolicConstant specifying the optimization task algorithm. Possible values are
            GENERAL_OPTIMIZATION and CONDITION_BASED_OPTIMIZATION. The default value is
            GENERAL_OPTIMIZATION.
        densityMoveLimit
            A Float specifying the maximum density change per design cycle. The default value is
            0.25.
        densityUpdateStrategy
            A SymbolicConstant specifying the strategy for how the densities are updated in the
            method of moving asymptotes. Possible values are NORMAL, CONSERVATIVE, and AGGRESSIVE.
            The default value is NORMAL.
        elementDensityDeltaStopCriteria
            A Float specifying the stop criteria based upon the change in element densities. The
            default value is 0.5×10-2.
        filterRadius
            None or a Float specifying the mesh filter radius for mesh independence and minimum
            size. The default value is None.
        firstCycleDeletedVolume
            A Float specifying the volume that can be removed immediately in the first design cycle.
            The default value is 5.0.
        firstCycleDeletedVolumeTechnique
            A SymbolicConstant specifying the method of quantifying volume that can be removed
            immediately in the first design cycle. Possible values are OFF, PERCENTAGE, and
            ABSOLUTE. The default value is OFF.
        freezeBoundaryConditionRegions
            A Boolean specifying whether to exclude elements with boundary conditions from the
            optimization. The default value is OFF.
        freezeLoadRegions
            A Boolean specifying whether to exclude elements with loads and elements with loaded
            nodes from the optimization. The default value is ON.
        frequencySpectrumWeight
            A Float specifying the weighting factor for frequency spectrum peaks. The default value
            is 6.0.
        initialDensity
            A SymbolicConstant specifying the Optimization product default or a float specifying the
            initial density. The default value is DEFAULT.
        materialInterpolationPenalty
            A Float specifying the penalty factor for the material interpolation technique. The
            default value is 3.0.
        materialInterpolationTechnique
            A SymbolicConstant specifying the material interpolation technique: optimization product
            default, solid isotropic material with penalization, or rational approximation of
            material properties. Possible values are DEFAULT, SIMP, and RAMP. The default value is
            DEFAULT.
        maxDensity
            A Float specifying the maximum density in the density update. The default value is 1.0.
        minDensity
            A Float specifying the minimum density in the density update. The default value is 10-3.
        modeTrackingRegion
            The SymbolicConstant MODEL or a Region object specifying the region to use for mode
            tracking. The default value is MODEL.
        numDesignCycles
            An Int specifying the number of design cycles permitted when **stepSize** is DYNAMIC. The
            default value is 15.
        numFulfilledStopCriteria
            An Int specifying the number of stop criteria. The default value is 2.
        numTrackedModes
            An Int specifying the number of modes included in mode tracking. The default value is 5.
        objectiveFunctionDeltaStopCriteria
            A Float specifying the stop criteria based on the change in objective function. The
            default value is 10-3.
        region
            The SymbolicConstant MODEL or a Region object specifying the region to which the
            optimization task is applied. The default value is MODEL.
        softDeletionMethod
            A SymbolicConstant specifying the method used when **softDeletionRegion** is specified.
            The STANDARD method avoids creating disconnected regions. The AGGRESSIVE method only
            considers the **softDeletionThreshold**. The MAX_SHEAR_STRAIN, MAX_ELASTOPLASTIC_STRAIN
            and VOLUME_COMPRESSION methods do not need the **softDeletionRadius**. Possible values are
            STANDARD, AGGRESSIVE, MAX_SHEAR_STRAIN, MIN_PRINCIPAL_STRAIN, MAX_ELASTOPLASTIC_STRAIN
            and VOLUME_COMPRESSION. The default value is STANDARD.
        softDeletionRadius
            A Float specifying the radius to use when considering neighboring soft elements to
            delete. The default value is 0.0.
        softDeletionRegion
            None or a Region object specifying the region in which the soft elements should be
            deleted during optimization. The default value is None.
        softDeletionThreshold
            A Float specifying the relative material density value used to identify soft elements.
            Those with values below the threshold are considered for removal. For STANDARD and
            AGGRESSIVE methods positive values are accepted and the default value is 0.05. For
            MAX_SHEAR_STRAIN and MAX_ELASTOPLASTIC_STRAIN methods positive values are accepted
            whereas for MIN_PRINCIPAL_STRAIN and VOLUME_COMPRESSION methods negative values are
            accepted.
        stepSize
            A SymbolicConstant specifying the size of the increment for volume modification.
            Possible values are DYNAMIC, VERY_SMALL, SMALL, MODERATE, MEDIUM, and LARGE. The default
            value is MEDIUM.
        stiffnessMassDamping
            The SymbolicConstant AVERAGE_EDGE_LENGTH or a Float specifying the stiffness mass
            damping for the task region. The default value is AVERAGE_EDGE_LENGTH.
        stopCriteriaDesignCycle
            An Int specifying the first design cycle used to evaluate convergence criteria. The
            default value is 4.
        structuralMassDamping
            None or a Float specifying the structural mass damping for the task region. The default
            value is None.
        viscousMassDamping
            None or a Float specifying the viscous mass damping for the task region. The default
            value is None.
        viscousStiffnessDamping
            None or a Float specifying the viscous stiffness damping for the task region. The
            default value is None.

        Returns
        -------
        TopologyTask
            A :py:class:`~abaqus.Optimization.TopologyTask.TopologyTask` object.
        """
        super().__init__()
        pass

    def setValues(
        self,
        abaqusSensitivities: Boolean = True,
        algorithm: SymbolicConstant = GENERAL_OPTIMIZATION,
        densityMoveLimit: float = 0,
        densityUpdateStrategy: SymbolicConstant = NORMAL,
        elementDensityDeltaStopCriteria: float = 0,
        filterRadius: float = None,
        firstCycleDeletedVolume: float = 5,
        firstCycleDeletedVolumeTechnique: SymbolicConstant = OFF,
        freezeBoundaryConditionRegions: Boolean = OFF,
        freezeLoadRegions: Boolean = ON,
        frequencySpectrumWeight: float = 6,
        initialDensity: SymbolicConstant = DEFAULT,
        materialInterpolationPenalty: float = 3,
        materialInterpolationTechnique: SymbolicConstant = DEFAULT,
        maxDensity: float = 1,
        minDensity: float = None,
        modeTrackingRegion: SymbolicConstant = MODEL,
        numDesignCycles: int = 15,
        numFulfilledStopCriteria: int = 2,
        numTrackedModes: int = 5,
        objectiveFunctionDeltaStopCriteria: float = None,
        region: SymbolicConstant = MODEL,
        softDeletionMethod: SymbolicConstant = STANDARD,
        softDeletionRadius: float = 0,
        softDeletionRegion: str = None,
        softDeletionThreshold: float = None,
        stepSize: SymbolicConstant = MEDIUM,
        stiffnessMassDamping: typing.Union[
            SymbolicConstant, float
        ] = AVERAGE_EDGE_LENGTH,
        stopCriteriaDesignCycle: int = 4,
        structuralMassDamping: float = None,
        viscousMassDamping: float = None,
        viscousStiffnessDamping: float = None,
    ):
        """This method modifies the TopologyTask object.

        Parameters
        ----------
        abaqusSensitivities
            A Boolean specifying whether to use Abaqus to compute the design responses and their
            sensitivities. The default value is True.
        algorithm
            A SymbolicConstant specifying the optimization task algorithm. Possible values are
            GENERAL_OPTIMIZATION and CONDITION_BASED_OPTIMIZATION. The default value is
            GENERAL_OPTIMIZATION.
        densityMoveLimit
            A Float specifying the maximum density change per design cycle. The default value is
            0.25.
        densityUpdateStrategy
            A SymbolicConstant specifying the strategy for how the densities are updated in the
            method of moving asymptotes. Possible values are NORMAL, CONSERVATIVE, and AGGRESSIVE.
            The default value is NORMAL.
        elementDensityDeltaStopCriteria
            A Float specifying the stop criteria based upon the change in element densities. The
            default value is 0.5×10-2.
        filterRadius
            None or a Float specifying the mesh filter radius for mesh independence and minimum
            size. The default value is None.
        firstCycleDeletedVolume
            A Float specifying the volume that can be removed immediately in the first design cycle.
            The default value is 5.0.
        firstCycleDeletedVolumeTechnique
            A SymbolicConstant specifying the method of quantifying volume that can be removed
            immediately in the first design cycle. Possible values are OFF, PERCENTAGE, and
            ABSOLUTE. The default value is OFF.
        freezeBoundaryConditionRegions
            A Boolean specifying whether to exclude elements with boundary conditions from the
            optimization. The default value is OFF.
        freezeLoadRegions
            A Boolean specifying whether to exclude elements with loads and elements with loaded
            nodes from the optimization. The default value is ON.
        frequencySpectrumWeight
            A Float specifying the weighting factor for frequency spectrum peaks. The default value
            is 6.0.
        initialDensity
            A SymbolicConstant specifying the Optimization product default or a float specifying the
            initial density. The default value is DEFAULT.
        materialInterpolationPenalty
            A Float specifying the penalty factor for the material interpolation technique. The
            default value is 3.0.
        materialInterpolationTechnique
            A SymbolicConstant specifying the material interpolation technique: optimization product
            default, solid isotropic material with penalization, or rational approximation of
            material properties. Possible values are DEFAULT, SIMP, and RAMP. The default value is
            DEFAULT.
        maxDensity
            A Float specifying the maximum density in the density update. The default value is 1.0.
        minDensity
            A Float specifying the minimum density in the density update. The default value is 10-3.
        modeTrackingRegion
            The SymbolicConstant MODEL or a Region object specifying the region to use for mode
            tracking. The default value is MODEL.
        numDesignCycles
            An Int specifying the number of design cycles permitted when **stepSize** is DYNAMIC. The
            default value is 15.
        numFulfilledStopCriteria
            An Int specifying the number of stop criteria. The default value is 2.
        numTrackedModes
            An Int specifying the number of modes included in mode tracking. The default value is 5.
        objectiveFunctionDeltaStopCriteria
            A Float specifying the stop criteria based on the change in objective function. The
            default value is 10-3.
        region
            The SymbolicConstant MODEL or a Region object specifying the region to which the
            optimization task is applied. The default value is MODEL.
        softDeletionMethod
            A SymbolicConstant specifying the method used when **softDeletionRegion** is specified.
            The STANDARD method avoids creating disconnected regions. The AGGRESSIVE method only
            considers the **softDeletionThreshold**. The MAX_SHEAR_STRAIN, MAX_ELASTOPLASTIC_STRAIN
            and VOLUME_COMPRESSION methods do not need the **softDeletionRadius**. Possible values are
            STANDARD, AGGRESSIVE, MAX_SHEAR_STRAIN, MIN_PRINCIPAL_STRAIN, MAX_ELASTOPLASTIC_STRAIN
            and VOLUME_COMPRESSION. The default value is STANDARD.
        softDeletionRadius
            A Float specifying the radius to use when considering neighboring soft elements to
            delete. The default value is 0.0.
        softDeletionRegion
            None or a Region object specifying the region in which the soft elements should be
            deleted during optimization. The default value is None.
        softDeletionThreshold
            A Float specifying the relative material density value used to identify soft elements.
            Those with values below the threshold are considered for removal. For STANDARD and
            AGGRESSIVE methods positive values are accepted and the default value is 0.05. For
            MAX_SHEAR_STRAIN and MAX_ELASTOPLASTIC_STRAIN methods positive values are accepted
            whereas for MIN_PRINCIPAL_STRAIN and VOLUME_COMPRESSION methods negative values are
            accepted.
        stepSize
            A SymbolicConstant specifying the size of the increment for volume modification.
            Possible values are DYNAMIC, VERY_SMALL, SMALL, MODERATE, MEDIUM, and LARGE. The default
            value is MEDIUM.
        stiffnessMassDamping
            The SymbolicConstant AVERAGE_EDGE_LENGTH or a Float specifying the stiffness mass
            damping for the task region. The default value is AVERAGE_EDGE_LENGTH.
        stopCriteriaDesignCycle
            An Int specifying the first design cycle used to evaluate convergence criteria. The
            default value is 4.
        structuralMassDamping
            None or a Float specifying the structural mass damping for the task region. The default
            value is None.
        viscousMassDamping
            None or a Float specifying the viscous mass damping for the task region. The default
            value is None.
        viscousStiffnessDamping
            None or a Float specifying the viscous stiffness damping for the task region. The
            default value is None.
        """
        pass



from .ConstrainedSketchConstraint.ConstrainedSketchConstraint import (
    ConstrainedSketchConstraint,
)
from .ConstrainedSketchDimension.ConstrainedSketchDimension import (
    ConstrainedSketchDimension,
)
from .ConstrainedSketchOptions.ConstrainedSketchImageOptions import (
    ConstrainedSketchImageOptions,
)
from .ConstrainedSketchOptions.ConstrainedSketchOptions import ConstrainedSketchOptions
from .ConstrainedSketchParameter.ConstrainedSketchParameter import (
    ConstrainedSketchParameter,
)
from .ConstrainedSketchVertex.ConstrainedSketchVertexArray import (
    ConstrainedSketchVertexArray,
)
from .ConstrainedSketchGeometry.ConstrainedSketchGeometryArray import (
    ConstrainedSketchGeometryArray
)


class ConstrainedSketchBase:
    """A :py:class:`~abaqus.Sketcher.ConstrainedSketch.ConstrainedSketch` object contains the entities that are used to create a sketch. The
    objects include ConstrainedSketchGeometry objects contained in the ConstrainedSketchGeometry Repository,
    such as Line, Arc, and Spline. ConstrainedSketchVertex, ConstrainedSketchDimension, ConstrainedSketchConstraint, and ConstrainedSketchParameter objects are
    contained in their respective repositories.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import sketch
            mdb.models[name].sketches[name]
    """

    #: A repository of ConstrainedSketchConstraint objects.
    constraints: dict[str, ConstrainedSketchConstraint] = dict[
        str, ConstrainedSketchConstraint
    ]()

    #: A repository of ConstrainedSketchDimension objects.
    dimensions: dict[str, ConstrainedSketchDimension] = dict[
        str, ConstrainedSketchDimension
    ]()

    #: A :py:class:`~abaqus.Amplitude.ConstrainedSketchGeometryArray.ConstrainedSketchGeometryArray` object specifying the sketch geometry, such as lines,
    #: arcs, circles, and splines.
    geometry: ConstrainedSketchGeometryArray = ConstrainedSketchGeometryArray()

    #: A repository of ConstrainedSketchParameter objects specifying sketch parameters, which
    #: may be associated with dimensions.
    parameters: dict[str, ConstrainedSketchParameter] = dict[
        str, ConstrainedSketchParameter
    ]()

    #: A :py:class:`~abaqus.Sketcher.ConstrainedSketchOptions.ConstrainedSketchOptions.ConstrainedSketchOptions` object specifying the sketch option settings.
    sketchOptions: ConstrainedSketchOptions = ConstrainedSketchOptions()

    #: A :py:class:`~abaqus.Sketcher.ConstrainedSketchVertex.ConstrainedSketchVertexArray.ConstrainedSketchVertexArray` object.
    vertices: ConstrainedSketchVertexArray = ConstrainedSketchVertexArray()

    #: A :py:class:`~abaqus.Sketcher.ConstrainedSketchOptions.ConstrainedSketchImageOptions.ConstrainedSketchImageOptions` object.
    imageOptions: ConstrainedSketchImageOptions = ConstrainedSketchImageOptions()



class InteractionProperty:
    """The InteractionProperty object is the abstract base type for other InteractionProperty
    objects. The InteractionProperty object has no explicit constructor, members, or
    methods.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactionProperties[name]

            The corresponding analysis keywords are:
    """

    pass



from .ConstrainedSketchConstraint import ConstrainedSketchConstraint
from ..ConstrainedSketchGeometry.ConstrainedSketchGeometry import (
    ConstrainedSketchGeometry,
)
from ...BasicGeometry.Vertex import Vertex


class EqualDistanceConstraint(ConstrainedSketchConstraint):
    def __init__(
        self, entity1: str, entity2: ConstrainedSketchGeometry, midpoint: Vertex
    ):
        """This method creates an equal distance constraint. This constraint can be applied between
        a midpoint ConstrainedSketchVertex object and any other two ConstrainedSketchVertex objects or between a midpoint ConstrainedSketchVertex
        object and two ConstrainedSketchGeometry objects that are lines. The equal distance
        constraint forces the midpoint vertex to remain at an equal distance from the two other
        vertices or lines.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].sketches[name].EqualDistanceConstraint

        Parameters
        ----------
        entity1
            AConstrainedSketchGeometry object specifying the first line or ConstrainedSketchVertex object.
        entity2
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry` object specifying the second line or ConstrainedSketchVertex object.
        midpoint
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchVertex.ConstrainedSketchVertex.ConstrainedSketchVertex` object specifying the vertex that will be positioned an equal distance from
            **entity1** and **entity2**.

        Returns
        -------
        ConstrainedSketchConstraint
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchConstraint.ConstrainedSketchConstraint.ConstrainedSketchConstraint` object.

        """
        pass



from .MdbDataFrameArray import MdbDataFrameArray


class MdbDataStep:
    """The MdbDataStep object.It corresponds to same named step in the cae model.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.mdbData[name].steps[i]
    """

    #: A :py:class:`~abaqus.PlotOptions.MdbDataFrameArray.MdbDataFrameArray` object specifying the list of frames. The list is read-only. There
    #: is only one frame in a step.
    frames: MdbDataFrameArray = MdbDataFrameArray()



from abaqusConstants import *


class TensionCutOff:
    """The TensionCutOff object specifies tension cutoff for different material models for
    example the Mohr-Coulomb plasticity model.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].mohrCoulombPlasticity.tensionCutOff
            import odbMaterial
            session.odbs[name].materials[name].mohrCoulombPlasticity.tensionCutOff

        The table data for this object are:

        - Tension cutoff stress.
        - The value of the corresponding tensile Plastic strain.(The first tabular value
          entered must always be zero.)
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - TENSION CUTOFF
    """

    def __init__(
        self, table: tuple, temperatureDependency: Boolean = OFF, dependencies: int = 0
    ):
        """This method creates a TensionCutOff object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].mohrCoulombPlasticity.TensionCutOff
                session.odbs[name].materials[name].mohrCoulombPlasticity.TensionCutOff

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        TensionCutOff
            A :py:class:`~abaqus.Material.Plastic.MohrCoulomb.TensionCutOff.TensionCutOff` object.

        Raises
        ------
        RangeError
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the TensionCutOff object.

        Raises
        ------
        RangeError
        """
        pass



from abaqusConstants import *


class GraphicsOptions:
    """The GraphicsOptions object stores settings that control how objects are rendered in all
    viewports. GraphicsOptions objects are accessed in one of two ways:
    - The default graphics options. These settings are used as defaults when you start a
    session and by the Defaults button on the Graphics ConstrainedSketchOptions dialog box.
    - The current graphics options.
    The GraphicsOptions object has no constructor; Abaqus creates both the
    **defaultGraphicsOptions** and the **graphicsOptions** members when a session is started.
    When you start a session, Abaqus detects the graphics hardware installed on your system
    and uses the setValues method in the environment file (abaqus_v6.env ) to modify the
    members of the GraphicsOptions object. If your graphics hardware is not supported by
    Abaqus/CAE, or if you wish to override the default graphics options, you can modify
    settings in the environment file. For more information, see Tuning graphics cards.

    Notes
    -----
    This object can be accessed by:

    .. code-block::

        session.defaultGraphicsOptions
        session.graphicsOptions
    """

    #: A Boolean specifying whether a viewport background style of GRADIENT can be overridden
    #: when displaying certain objects, such as sketches or XY plots. When overridden, the
    #: background will be the top color of the gradient background.
    backgroundOverride: Boolean = OFF

    #: A Boolean specifying whether facets that are determined to be facing away from the
    #: viewer will be drawn. The default value is ON. backfaceCulling provides a performance
    #: enhancement when displaying solid elements where the front side of the element occludes
    #: the back side of the element. Set **backfaceCulling** = OFF if it appears that you are
    #: seeing the back side of an element and the front side is missing. You should also set
    #: **backfaceCulling** = OFF if you believe the display is not complete.
    backfaceCulling: Boolean = ON

    #: A SymbolicConstant specifying the graphics driver to use. Abaqus/CAE currently uses
    #: OpenGL exclusively so the only possible value is OPEN_GL. OPEN_GL takes advantage of
    #: graphics adapter hardware acceleration.
    graphicsDriver: SymbolicConstant = None

    #: A Boolean specifying whether double buffering is used. The default value is ON.Double
    #: buffering controls where Abaqus/CAE draws its graphics. When **doubleBuffering** = OFF,
    #: everything is drawn directly to the screen and on many systems you can see the progress
    #: of the drawing operations. Most users find this distracting, especially in dynamic
    #: situations such as view manipulation or animation of results. When **doubleBuffering** = ON,
    #: the drawing occurs in a separate graphics buffer that is displayed when all the drawing
    #: operations are complete. This results in a much smoother display during view changes or
    #: animation. It is recommended that you set double buffering to ON.
    doubleBuffering: Boolean = ON

    #: A Boolean specifying whether a display list will be used to accelerate graphics
    #: performance. The default value is ON.When **displayLists** = ON, drawing operations are
    #: recorded in a list that can be quickly replayed. This results in faster drawing on most
    #: systems but requires extra memory to record the drawing operations. In the Visualization
    #: module, display lists are only used during view manipulations and then their use is
    #: subject to the setting of **viewManipDisplayListThreshold**.
    displayLists: Boolean = ON

    #: A SymbolicConstant specifying which rendering is used during dynamic rotations of the
    #: view. Possible values are:FAST, specifying a rendering mode where the image is rendered
    #: in wireframe.AS_IS, specifying a rendering mode where the image is rendered as is.The
    #: default value is AS_IS.When set to **dragMode** = FAST, a wireframe outline is drawn during
    #: view changes by rotation, pan, or zoom. When **dragMode** = AS_IS, everything displayed in
    #: the window will be drawn during view changes; however, the display may lag behind the
    #: mouse movement when the model is complex especially if you are using an older or slower
    #: system. For newer systems with graphics hardware acceleration the AS_IS setting can be
    #: accommodated without significant loss of performance.
    dragMode: SymbolicConstant = AS_IS

    #: A Boolean specifying whether lines will be smoothed to reduce the jagged effect of
    #: rasterization. The default value is ON.
    antiAlias: Boolean = ON

    #: A Boolean specifying whether the model is automatically resized to fit the viewport
    #: after each view rotation. The default value is OFF.
    autoFitAfterRotate: Boolean = OFF

    #: A Float specifying the offset added when drawing the faces of a polygon. The
    #: **polygonOffsetConstant** argument affects the behavior of only the OpenGL driver.
    #: Possible values are 0.0 ≤≤ **polygonOffsetConstant** ≤≤ 100.0. The default value is
    #: platform dependent and is typically between 0.0 and 2.0.
    polygonOffsetConstant: float = None

    #: A Float specifying the factor that multiplies the slope of each line before the line is
    #: added to the vertexes of a polygon face. The **polygonOffsetSlope** argument affects the
    #: behavior of only the OpenGL driver. Possible values are 0.0 ≤≤ **polygonOffsetSlope** ≤≤
    #: 100.0. The default value is platform dependent and is typically between 0.0 and 2.0.
    polygonOffsetSlope: float = None

    #: A Float specifying the offset added when drawing the faces of a polygon.
    #: **printPolygonOffsetConstant** is similar to **polygonOffsetConstant**; however,
    #: **printPolygonOffsetConstant** is used when printing and **polygonOffsetConstant** is used
    #: for display. Some systems, especially Windows, use different OpenGL drivers for printing
    #: and display, and you may have to use different offset values for each driver.
    printPolygonOffsetConstant: float = None

    #: A Float specifying the factor that multiplies the slope of each line before the line is
    #: added to the vertexes of a polygon face. **printPolygonOffsetSlope** is similar to
    #: **polygonOffsetSlope**; however, **printPolygonOffsetSlope** is used when printing and
    #: **polygonOffsetSlope** is used for display. Some systems, especially Windows, use
    #: different OpenGL drivers for printing and display, and you may have to use different
    #: offset values for each driver.
    printPolygonOffsetSlope: float = None

    #: A Boolean specifying how the three-dimensional vertices of the model are processed. When
    #: **vertexArrays** = OFF, each vertex of the model is processed separately. When
    #: **vertexArrays** = ON, the vertices are processed in large blocks resulting in faster
    #: display. Not all graphics adapters support this capability correctly. An indicator that
    #: the graphics adapters is not processing three-dimensional vertices correctly is the
    #: absence of graphics during rubber banding operations. For example, when dynamically
    #: dragging the radius of a circle in the Sketcher, the circle should be visible. The
    #: default value is ON.
    vertexArrays: Boolean = ON

    #: A Boolean specifying whether the **vertexArrays** setting should temporarily be set to OFF
    #: when building a display list. The default value is ON.Some graphics adapters do not
    #: properly support using vertex arrays inside a display list. Setting
    #: **vertexArraysInDisplayLists** to OFF has a smaller impact on graphics performance than
    #: setting **vertexArrays** or **displayLists** to OFF.
    vertexArraysInDisplayLists: Boolean = ON

    #: An Int specifying how large a display list may be created in order to accelerate view
    #: manipulation operations. Increasing this value when viewing large models will increase
    #: the delay before a view manipulation operation begins in order to obtain improved
    #: graphics performance during the view manipulation. If set high with a large model, the
    #: delay can be many seconds. In excessive cases, graphics memory can be exceeded and the
    #: result may be an empty display list (no visible model) for the view manipulation. This
    #: setting is treated as 0 if **displayLists** = OFF. Possible values are 0 ≤≤
    #: **viewManipDisplayListThreshold** ≤≤ 20000. The default value is 40.
    viewManipDisplayListThreshold: int = 40

    #: A Boolean specifying how Abaqus renders X11 graphics operations. When
    #: **directRendering** = OFF, the graphics are rendered through the X Server. When
    #: **directRendering** = ON, the graphics operations are sent directly to the graphics adapter
    #: producing faster displays. For maximum performance, the initial value is ON. This
    #: argument is used only when you first start Abaqus/CAE; you cannot configure
    #: **directRendering** during a session.
    directRendering: Boolean = OFF

    #: A Boolean specifying whether a hardware accelerated OpenGL graphics driver will be used
    #: on Windows platforms. The default value is ON.When **hardwareAcceleration** = OFF, the
    #: graphics driver uses a software implementation of OpenGL that is included with the
    #: operating system. This results in slower drawing on most systems; however, you may have
    #: to use the software implementation of OpenGL if the hardware graphics driver is
    #: incompatible with Abaqus/CAE.*hardwareAcceleration* is used only when you first start
    #: Abaqus/CAE on a Windows platform; you cannot configure **hardwareAcceleration** during a
    #: session.*hardwareAcceleration* is not used when you start Abaqus/CAE on an X-Windows
    #: platform and display to a Windows platform running Exceed or any other X-Windows server.
    hardwareAcceleration: Boolean = ON

    #: A Boolean specifying whether hardware overlay planes will be used if available. The
    #: default value is the same value as the **hardwareOverlayAvailable** member.When
    #: **hardwareOverlayAvailable** = OFF, it will not be possible to set **hardwareOverlay** to ON
    #: and the HARDWARE_OVERLAY highlight method will not be available. If viewports display a
    #: solid color and will not display the model, it will be necessary to inhibit hardware
    #: overlay completely by setting the ABAQUS_EMULATE_OVERLAYS environment variable (to any
    #: value) before starting Abaqus/CAE.*hardwareOverlay* is used only when you first start
    #: Abaqus/CAE; you cannot configure **hardwareOverlay** during a session.
    hardwareOverlay: Boolean = OFF

    #: A Boolean specifying whether textures will be used to display contour plots. The default
    #: value is ON.Turning off texture mapping is necessary only if viewports will not
    #: correctly display a contour plot of your model.
    textureMapping: Boolean = ON

    #: A Boolean specifying whether textures will be used to display contour plots. The default
    #: value is ON.Turning off texture mapping for printing is necessary only if printed output
    #: does not correctly display a contour plot of your model. **printTextureMapping** is
    #: similar to **textureMapping**; however, **printTextureMapping** is used when printing and
    #: **textureMapping** is used for display. Some systems, especially Windows, use different
    #: OpenGL drivers for printing and display, and you may have to use different settings for
    #: each driver.
    printTextureMapping: Boolean = ON

    #: A SymbolicConstant specifying the background style to be used for all viewport windows.
    #: Possible values are SOLID and GRADIENT. The default value is SOLID.If
    #: **backgroundStyle** = SOLID, the viewport background will appear as a solid color as
    #: specified by **backgroundColor**. If **backgroundStyle** = GRADIENT, the viewport background
    #: will be drawn as a gradient beginning with the **backgroundColor** at the top of the
    #: viewport and gradually blending to the **backgroundBottomColor** at the bottom of the
    #: viewport.
    backgroundStyle: SymbolicConstant = SOLID

    #: A Boolean specifying whether the hardware accelerated graphics driver will be used for
    #: off-screen rendering. The default value is ON if graphics hardware acceleration is
    #: available and has not been disabled via the hardwareAcceleration option, and the
    #: graphics driver supports the underlying technology. When set to OFF, an alternate
    #: (slower) technique will be used to create off-screen images. Off-screen rendering is
    #: used for Printing, Probe, and backing store (viewport refresh). Setting this value to
    #: OFF will force printed images to be rendered without hardware acceleration. This is
    #: useful when writing automated tests to produce raster images that you will want to
    #: compare across multiple machines that may have different graphics environments.
    accelerateOffScreen: Boolean = OFF

    #: A Boolean specifying whether a backing store will be used to refresh a viewport after a
    #: window occluding the viewport is moved or dismissed. The default value is ON.
    backingStore: Boolean = ON

    #: A SymbolicConstant specifying the highlight method. For the GraphicsOptions object,
    #: possible values of the member are HARDWARE_OVERLAY, XOR, SOFTWARE_OVERLAY, and BLEND.
    highlightMethod: SymbolicConstant = None

    #: A Boolean specifying if the graphics hardware supports hardware overlay.
    hardwareOverlayAvailable: Boolean = OFF

    #: A Boolean specifying if the graphics hardware supports the OpenGL Shading Language
    #: (GLSL).
    shadersAvailable: Boolean = OFF

    #: An Int specifying whether speed or accuracy is more important when drawing translucent
    #: objects. Lower values optimize for speed while higher values optimize for accuracy. The
    #: actual meaning of each setting will depend on the setting of **shadersAvailable** and the
    #: capabilities of the graphics hardware and driver. Possible values are 1 ≤≤
    #: **translucencyMode** ≤≤ 6. The default value is 4.
    translucencyMode: int = 4

    #: A Float specifying a tolerance used when computing the appropriate scale for
    #: transforming result (contour) values to texture values. When set too low the 'out of
    #: range' colors may be incorrectly shown for values near the range limits. The default
    #: value is 0.5×10-5.
    contourRangeTexturePrecision: float = 0

    #: None or a GraphicsOptions object specifying the object from which values are to be
    #: copied. If other arguments are also supplied to setValues, they will override the values
    #: in the **options** member. The default value is None.
    options: str = None

    #: A tuple of SymbolicConstants specifying a hint used to modify the highlight method.
    #: Possible values are:HARDWARE_OVERLAY, specifying a hint of hardware overlay. The best
    #: graphics performance is achieved using hardware overlay, but not all systems and
    #: graphics adapters support hardware overlay.XOR, specifying a hint of XOR technique. The
    #: XOR technique uses a boolean pixel operation to simulate the drawing operations but can
    #: produce different colors depending on the color of the underlying
    #: pixels.SOFTWARE_OVERLAY, specifying a hint of software overlay. The software overlay
    #: method simulates the effect of hardware overlay.BLEND, specifying a hint of blend
    #: method. The blend method combines the color of the underlying pixel with the desired
    #: color producing an approximation of the transient graphics.The default value is
    #: (HARDWARE_OVERLAY, XOR, SOFTWARE_OVERLAY, BLEND).The values of this sequence are applied
    #: by Abaqus when you start a session in first to last order. The first successful value
    #: becomes the default highlight method. Not all graphics adapters support the
    #: HARDWARE_OVERLAY value and you must use the **highlightMethodHint** argument to provide an
    #: alternative.You can use a single value to set the first element of the list, or you can
    #: use a tuple with one to four unique values. Abaqus sets any remaining elements of the
    #: tuple to unique values based on the default order.
    highlightMethodHint: SymbolicConstant = None

    #: A String specifying one of the two background colors for all viewport windows. The
    #: initial color is black. A list of valid color strings is in the **colors** map in the
    #: Session object.
    backgroundColor: str = ""

    #: A String specifying one of the two background colors for all viewport windows. This
    #: color is used only if **backgroundStyle** =GRADIENT. The initial color is black. A list of
    #: valid color strings is in the **colors** map in the Session object.
    backgroundBottomColor: str = ""

    def setValues(
        self,
        graphicsDriver: SymbolicConstant = None,
        doubleBuffering: Boolean = ON,
        displayLists: Boolean = ON,
        highlightMethodHint: SymbolicConstant = None,
        dragMode: SymbolicConstant = AS_IS,
        antiAlias: Boolean = ON,
        autoFitAfterRotate: Boolean = OFF,
        polygonOffsetConstant: float = None,
        polygonOffsetSlope: float = None,
        printPolygonOffsetConstant: float = None,
        printPolygonOffsetSlope: float = None,
        vertexArrays: Boolean = ON,
        vertexArraysInDisplayLists: Boolean = ON,
        viewManipDisplayListThreshold: int = 40,
        directRendering: Boolean = OFF,
        hardwareAcceleration: Boolean = ON,
        hardwareOverlay: Boolean = OFF,
        textureMapping: Boolean = ON,
        printTextureMapping: Boolean = ON,
        backgroundStyle: SymbolicConstant = SOLID,
        backgroundColor: str = "",
        backgroundBottomColor: str = "",
        backgroundOverride: Boolean = OFF,
        backfaceCulling: Boolean = ON,
        accelerateOffScreen: Boolean = OFF,
        backingStore: Boolean = ON,
        shadersAvailable: Boolean = OFF,
        translucencyMode: int = 4,
        options: str = None,
        contourRangeTexturePrecision: float = 0,
    ):
        """This method modifies the GraphicsOptions object.

        Parameters
        ----------
        graphicsDriver
            A SymbolicConstant specifying the graphics driver to use. Abaqus/CAE currently uses
            OpenGL exclusively so the only possible value is OPEN_GL. OPEN_GL takes advantage of
            graphics adapter hardware acceleration.
        doubleBuffering
            A Boolean specifying whether double buffering is used. The default value is ON.Double
            buffering controls where Abaqus/CAE draws its graphics. When **doubleBuffering** = OFF,
            everything is drawn directly to the screen and on many systems you can see the progress
            of the drawing operations. Most users find this distracting, especially in dynamic
            situations such as view manipulation or animation of results. When **doubleBuffering** = ON,
            the drawing occurs in a separate graphics buffer that is displayed when all the drawing
            operations are complete. This results in a much smoother display during view changes or
            animation. It is recommended that you set double buffering to ON.
        displayLists
            A Boolean specifying whether a display list will be used to accelerate graphics
            performance. The default value is ON.When **displayLists** = ON, drawing operations are
            recorded in a list that can be quickly replayed. This results in faster drawing on most
            systems but requires extra memory to record the drawing operations. In the Visualization
            module, display lists are only used during view manipulations and then their use is
            subject to the setting of **viewManipDisplayListThreshold**.
        highlightMethodHint
            A sequence of SymbolicConstants specifying a hint used to modify the highlight method.
            Possible values are:HARDWARE_OVERLAY, specifying a hint of hardware overlay. The best
            graphics performance is achieved using hardware overlay, but not all systems and
            graphics adapters support hardware overlay.XOR, specifying a hint of XOR technique. The
            XOR technique uses a boolean pixel operation to simulate the drawing operations but can
            produce different colors depending on the color of the underlying
            pixels.SOFTWARE_OVERLAY, specifying a hint of software overlay. The software overlay
            method simulates the effect of hardware overlay.BLEND, specifying a hint of blend
            method. The blend method combines the color of the underlying pixel with the desired
            color producing an approximation of the transient graphics.The default value is
            (HARDWARE_OVERLAY, XOR, SOFTWARE_OVERLAY, BLEND).The values of this sequence are applied
            by Abaqus when you start a session in first to last order. The first successful value
            becomes the default highlight method. Not all graphics adapters support the
            HARDWARE_OVERLAY value and you must use the **highlightMethodHint** argument to provide an
            alternative.You can use a single value to set the first element of the list, or you can
            use a tuple with one to four unique values. Abaqus sets any remaining elements of the
            tuple to unique values based on the default order.
        dragMode
            A SymbolicConstant specifying which rendering is used during dynamic rotations of the
            view. Possible values are:FAST, specifying a rendering mode where the image is rendered
            in wireframe.AS_IS, specifying a rendering mode where the image is rendered as is.The
            default value is AS_IS.When set to **dragMode** = FAST, a wireframe outline is drawn during
            view changes by rotation, pan, or zoom. When **dragMode** = AS_IS, everything displayed in
            the window will be drawn during view changes; however, the display may lag behind the
            mouse movement when the model is complex especially if you are using an older or slower
            system. For newer systems with graphics hardware acceleration the AS_IS setting can be
            accommodated without significant loss of performance.
        antiAlias
            A Boolean specifying whether lines will be smoothed to reduce the jagged effect of
            rasterization. The default value is ON.
        autoFitAfterRotate
            A Boolean specifying whether the model is automatically resized to fit the viewport
            after each view rotation. The default value is OFF.
        polygonOffsetConstant
            A Float specifying the offset added when drawing the faces of a polygon. The
            **polygonOffsetConstant** argument affects the behavior of only the OpenGL driver.
            Possible values are 0.0 ≤≤ **polygonOffsetConstant** ≤≤ 100.0. The default value is
            platform dependent and is typically between 0.0 and 2.0.
        polygonOffsetSlope
            A Float specifying the factor that multiplies the slope of each line before the line is
            added to the vertexes of a polygon face. The **polygonOffsetSlope** argument affects the
            behavior of only the OpenGL driver. Possible values are 0.0 ≤≤ **polygonOffsetSlope** ≤≤
            100.0. The default value is platform dependent and is typically between 0.0 and 2.0.
        printPolygonOffsetConstant
            A Float specifying the offset added when drawing the faces of a polygon.
            **printPolygonOffsetConstant** is similar to **polygonOffsetConstant**; however,
            **printPolygonOffsetConstant** is used when printing and **polygonOffsetConstant** is used
            for display. Some systems, especially Windows, use different OpenGL drivers for printing
            and display, and you may have to use different offset values for each driver.
        printPolygonOffsetSlope
            A Float specifying the factor that multiplies the slope of each line before the line is
            added to the vertexes of a polygon face. **printPolygonOffsetSlope** is similar to
            **polygonOffsetSlope**; however, **printPolygonOffsetSlope** is used when printing and
            **polygonOffsetSlope** is used for display. Some systems, especially Windows, use
            different OpenGL drivers for printing and display, and you may have to use different
            offset values for each driver.
        vertexArrays
            A Boolean specifying how the three-dimensional vertices of the model are processed. When
            **vertexArrays** = OFF, each vertex of the model is processed separately. When
            **vertexArrays** = ON, the vertices are processed in large blocks resulting in faster
            display. Not all graphics adapters support this capability correctly. An indicator that
            the graphics adapters is not processing three-dimensional vertices correctly is the
            absence of graphics during rubber banding operations. For example, when dynamically
            dragging the radius of a circle in the Sketcher, the circle should be visible. The
            default value is ON.
        vertexArraysInDisplayLists
            A Boolean specifying whether the **vertexArrays** setting should temporarily be set to OFF
            when building a display list. The default value is ON.Some graphics adapters do not
            properly support using vertex arrays inside a display list. Setting
            **vertexArraysInDisplayLists** to OFF has a smaller impact on graphics performance than
            setting **vertexArrays** or **displayLists** to OFF.
        viewManipDisplayListThreshold
            An Int specifying how large a display list may be created in order to accelerate view
            manipulation operations. Increasing this value when viewing large models will increase
            the delay before a view manipulation operation begins in order to obtain improved
            graphics performance during the view manipulation. If set high with a large model, the
            delay can be many seconds. In excessive cases, graphics memory can be exceeded and the
            result may be an empty display list (no visible model) for the view manipulation. This
            setting is treated as 0 if **displayLists** = OFF. Possible values are 0 ≤≤
            **viewManipDisplayListThreshold** ≤≤ 20000. The default value is 40.
        directRendering
            A Boolean specifying how Abaqus renders X11 graphics operations. When
            **directRendering** = OFF, the graphics are rendered through the X Server. When
            **directRendering** = ON, the graphics operations are sent directly to the graphics adapter
            producing faster displays. For maximum performance, the initial value is ON. This
            argument is used only when you first start Abaqus/CAE; you cannot configure
            **directRendering** during a session.
        hardwareAcceleration
            A Boolean specifying whether a hardware accelerated OpenGL graphics driver will be used
            on Windows platforms. The default value is ON.When **hardwareAcceleration** = OFF, the
            graphics driver uses a software implementation of OpenGL that is included with the
            operating system. This results in slower drawing on most systems; however, you may have
            to use the software implementation of OpenGL if the hardware graphics driver is
            incompatible with Abaqus/CAE.*hardwareAcceleration* is used only when you first start
            Abaqus/CAE on a Windows platform; you cannot configure **hardwareAcceleration** during a
            session.*hardwareAcceleration* is not used when you start Abaqus/CAE on an X-Windows
            platform and display to a Windows platform running Exceed or any other X-Windows server.
        hardwareOverlay
            A Boolean specifying whether hardware overlay planes will be used if available. The
            default value is the same value as the **hardwareOverlayAvailable** member.When
            **hardwareOverlayAvailable** = OFF, it will not be possible to set **hardwareOverlay** to ON
            and the HARDWARE_OVERLAY highlight method will not be available. If viewports display a
            solid color and will not display the model, it will be necessary to inhibit hardware
            overlay completely by setting the ABAQUS_EMULATE_OVERLAYS environment variable (to any
            value) before starting Abaqus/CAE.*hardwareOverlay* is used only when you first start
            Abaqus/CAE; you cannot configure **hardwareOverlay** during a session.
        textureMapping
            A Boolean specifying whether textures will be used to display contour plots. The default
            value is ON.Turning off texture mapping is necessary only if viewports will not
            correctly display a contour plot of your model.
        printTextureMapping
            A Boolean specifying whether textures will be used to display contour plots. The default
            value is ON.Turning off texture mapping for printing is necessary only if printed output
            does not correctly display a contour plot of your model. **printTextureMapping** is
            similar to **textureMapping**; however, **printTextureMapping** is used when printing and
            **textureMapping** is used for display. Some systems, especially Windows, use different
            OpenGL drivers for printing and display, and you may have to use different settings for
            each driver.
        backgroundStyle
            A SymbolicConstant specifying the background style to be used for all viewport windows.
            Possible values are SOLID and GRADIENT. The default value is SOLID.If
            **backgroundStyle** = SOLID, the viewport background will appear as a solid color as
            specified by **backgroundColor**. If **backgroundStyle** = GRADIENT, the viewport background
            will be drawn as a gradient beginning with the **backgroundColor** at the top of the
            viewport and gradually blending to the **backgroundBottomColor** at the bottom of the
            viewport.
        backgroundColor
            A String specifying one of the two background colors for all viewport windows. The
            initial color is black. A list of valid color strings is in the **colors** map in the
            Session object.
        backgroundBottomColor
            A String specifying one of the two background colors for all viewport windows. This
            color is used only if **backgroundStyle** =GRADIENT. The initial color is black. A list of
            valid color strings is in the **colors** map in the Session object.
        backgroundOverride
            A Boolean specifying whether a viewport background style of GRADIENT can be overridden
            when displaying certain objects, such as sketches or XY plots. When overridden, the
            background will be the top color of the gradient background.
        backfaceCulling
            A Boolean specifying whether facets that are determined to be facing away from the
            viewer will be drawn. The default value is ON. backfaceCulling provides a performance
            enhancement when displaying solid elements where the front side of the element occludes
            the back side of the element. Set **backfaceCulling** = OFF if it appears that you are
            seeing the back side of an element and the front side is missing. You should also set
            **backfaceCulling** = OFF if you believe the display is not complete.
        accelerateOffScreen
            A Boolean specifying whether the hardware accelerated graphics driver will be used for
            off-screen rendering. The default value is ON if graphics hardware acceleration is
            available and has not been disabled via the hardwareAcceleration option, and the
            graphics driver supports the underlying technology. When set to OFF, an alternate
            (slower) technique will be used to create off-screen images. Off-screen rendering is
            used for Printing, Probe, and backing store (viewport refresh). Setting this value to
            OFF will force printed images to be rendered without hardware acceleration. This is
            useful when writing automated tests to produce raster images that you will want to
            compare across multiple machines that may have different graphics environments.
        backingStore
            A Boolean specifying whether a backing store will be used to refresh a viewport after a
            window occluding the viewport is moved or dismissed. The default value is ON.
        shadersAvailable
            A Boolean specifying if the graphics hardware supports the OpenGL Shading Language
            (GLSL).
        translucencyMode
            An Int specifying whether speed or accuracy is more important when drawing translucent
            objects. Lower values optimize for speed while higher values optimize for accuracy. The
            actual meaning of each setting will depend on the setting of **shadersAvailable** and the
            capabilities of the graphics hardware and driver. Possible values are 1 ≤≤
            **translucencyMode** ≤≤ 6. The default value is 4.
        options
            None or a GraphicsOptions object specifying the object from which values are to be
            copied. If other arguments are also supplied to setValues, they will override the values
            in the **options** member. The default value is None.
        contourRangeTexturePrecision
            A Float specifying a tolerance used when computing the appropriate scale for
            transforming result (contour) values to texture values. When set too low the 'out of
            range' colors may be incorrectly shown for values near the range limits. The default
            value is 0.5×10-5.

        Raises
        ------
        RangeError
        """
        pass



from abaqusConstants import *
from .ContactProperty import ContactProperty


class IncidentWaveProperty(ContactProperty):
    """The IncidentWaveProperty object is an interaction property that defines the properties
    referred to by an IncidentWave object.
    The IncidentWaveProperty object is derived from the InteractionProperty object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactionProperties[name]

        The corresponding analysis keywords are:

        - INCIDENT WAVE INTERACTION PROPERTY
                - UNDEX CHARGE PROPERTY
                - CONWEP CHARGE PROPERTY
    """

    #: A String specifying the interaction property repository key.
    name: str

    #: A SymbolicConstant specifying the type of wave to be defined. Possible values are
    #: PLANAR, SPHERICAL, DIFFUSE, AIR_BLAST, and SURFACE_BLAST. The default value is PLANAR.
    definition: SymbolicConstant = PLANAR

    #: A SymbolicConstant specifying the spherical propagation model. Possible values are
    #: ACOUSTIC, UNDEX_CHARGE, and GENERALIZED_DECAY. The default value is ACOUSTIC.This
    #: argument is valid only when **definition** = SPHERICAL.
    propagationModel: SymbolicConstant = ACOUSTIC

    #: A Float specifying the speed of sound in the fluid.This argument is not valid when
    #: **definition** = AIR_BLAST or when **definition** = SURFACE_BLAST.
    soundSpeed: float = None

    #: A Float specifying the fluid mass density.This argument is not valid when
    #: **definition** = AIR_BLAST or when **definition** = SURFACE_BLAST.
    fluidDensity: float = None

    #: None or a Float specifying the ratio of specific heats for gas. The default value is
    #: None.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    specificHeatRatio: float = None

    #: None or a Float specifying the acceleration due to gravity. The default value is
    #: None.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    gravity: float = None

    #: None or a Float specifying the atmospheric pressure. The default value is None.This
    #: argument is valid only when **definition** = SPHERICAL and **propagationModel** = UNDEX_CHARGE.
    atmosphericPressure: float = None

    #: None or a Float specifying the fluid drag coefficient. The default value is None.This
    #: argument is valid only when **definition** = SPHERICAL and **propagationModel** = UNDEX_CHARGE.
    dragCoefficient: float = None

    #: A Float specifying the fluid drag exponent. The default value is 2.0.This argument is
    #: valid only when **definition** = SPHERICAL and **propagationModel** = UNDEX_CHARGE.
    dragExponent: float = 2

    #: A Boolean specifying whether or not to include wave effects in the fluid and gas. The
    #: default value is ON.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    waveEffects: Boolean = ON

    #: None or a Float specifying the density of the charge material. The default value is
    #: None.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    chargeDensity: float = None

    #: None or a Float specifying the mass of the charge material. The default value is
    #: None.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    chargeMass: float = None

    #: None or a Float specifying the charge material constant K. The default value is
    #: None.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    constantK1: float = None

    #: None or a Float specifying the charge material constant k. The default value is
    #: None.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    constantK2: float = None

    #: None or a Float specifying the charge material constant A. The default value is
    #: None.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    constantA: float = None

    #: None or a Float specifying the charge material constant B. The default value is
    #: None.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    constantB: float = None

    #: None or a Float specifying the charge material constant Kc. The default value is
    #: None.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    constantKc: float = None

    #: None or a Float specifying the time duration for the bubble simulation. The default
    #: value is None.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    duration: float = None

    #: An Int specifying the maximum number of time steps for the bubble simulation. The
    #: default value is 1500.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    maximumSteps: int = 1500

    #: A Float specifying the relative step size control parameter. The default value is
    #: 1x10-11.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    relativeStepControl: float = None

    #: A Float specifying the absolute step size control parameter. The default value is
    #: 1x10-11.This argument is valid only when **definition** = SPHERICAL and
    #: **propagationModel** = UNDEX_CHARGE.
    absoluteStepControl: float = None

    #: A Float specifying the step size control exponent. The default value is 0.2.This
    #: argument is valid only when **definition** = SPHERICAL and **propagationModel** = UNDEX_CHARGE.
    stepControlExponent: float = 0

    #: A Float specifying the constant A associated with the generalized decay propagation
    #: model. The default value is 0.0.This argument is valid only when **definition** = SPHERICAL
    #: and **propagationModel** = GENERALIZED_DECAY.
    genDecayA: float = 0

    #: A Float specifying the constant B associated with the generalized decay propagation
    #: model. The default value is 0.0.This argument is valid only when **definition** = SPHERICAL
    #: and **propagationModel** = GENERALIZED_DECAY.
    genDecayB: float = 0

    #: A Float specifying the constant C associated with the generalized decay propagation
    #: model. The default value is 0.0.This argument is valid only when **definition** = SPHERICAL
    #: and **propagationModel** = GENERALIZED_DECAY.
    genDecayC: float = 0

    #: An Int specifying the seed number (N) for the diffuse source calculation. N2 sources
    #: will be used in the simulation.This argument is valid only when **definition** = DIFFUSE.
    seedNumber: int = None

    #: A Float specifying the equivalent mass of TNT, in any preferred mass unit.This argument
    #: is valid only when **definition** = AIR_BLAST or **definition** = SURFACE_BLAST.
    massTNT: float = None

    #: A Float specifying the multiplication factor to convert from the preferred mass unit to
    #: kilograms. The default value is 1.0.This argument is valid only when
    #: **definition** = AIR_BLAST or **definition** = SURFACE_BLAST.
    massFactor: float = 1

    #: A Float specifying the multiplication factor to convert from the analysis length unit to
    #: meters. The default value is 1.0.This argument is valid only when **definition** = AIR_BLAST
    #: or **definition** = SURFACE_BLAST.
    lengthFactor: float = 1

    #: A Float specifying the multiplication factor to convert from the analysis time unit to
    #: seconds. The default value is 1.0.This argument is valid only when
    #: **definition** = AIR_BLAST or **definition** = SURFACE_BLAST.
    timeFactor: float = 1

    #: A Float specifying the multiplication factor to convert from the analysis pressure unit
    #: to pascals. The default value is 1.0.This argument is valid only when
    #: **definition** = AIR_BLAST or **definition** = SURFACE_BLAST.
    pressureFactor: float = 1

    def __init__(
        self,
        name: str,
        definition: SymbolicConstant = PLANAR,
        propagationModel: SymbolicConstant = ACOUSTIC,
        soundSpeed: float = None,
        fluidDensity: float = None,
        specificHeatRatio: float = None,
        gravity: float = None,
        atmosphericPressure: float = None,
        dragCoefficient: float = None,
        dragExponent: float = 2,
        waveEffects: Boolean = ON,
        chargeDensity: float = None,
        chargeMass: float = None,
        constantK1: float = None,
        constantK2: float = None,
        constantA: float = None,
        constantB: float = None,
        constantKc: float = None,
        duration: float = None,
        maximumSteps: int = 1500,
        relativeStepControl: float = None,
        absoluteStepControl: float = None,
        stepControlExponent: float = 0,
        genDecayA: float = 0,
        genDecayB: float = 0,
        genDecayC: float = 0,
        seedNumber: int = None,
        massTNT: float = None,
        massFactor: float = 1,
        lengthFactor: float = 1,
        timeFactor: float = 1,
        pressureFactor: float = 1,
    ):
        """This method creates an IncidentWaveProperty object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].IncidentWaveProperty

        Parameters
        ----------
        name
            A String specifying the interaction property repository key.
        definition
            A SymbolicConstant specifying the type of wave to be defined. Possible values are
            PLANAR, SPHERICAL, DIFFUSE, AIR_BLAST, and SURFACE_BLAST. The default value is PLANAR.
        propagationModel
            A SymbolicConstant specifying the spherical propagation model. Possible values are
            ACOUSTIC, UNDEX_CHARGE, and GENERALIZED_DECAY. The default value is ACOUSTIC.This
            argument is valid only when **definition** = SPHERICAL.
        soundSpeed
            A Float specifying the speed of sound in the fluid.This argument is not valid when
            **definition** = AIR_BLAST or when **definition** = SURFACE_BLAST.
        fluidDensity
            A Float specifying the fluid mass density.This argument is not valid when
            **definition** = AIR_BLAST or when **definition** = SURFACE_BLAST.
        specificHeatRatio
            None or a Float specifying the ratio of specific heats for gas. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        gravity
            None or a Float specifying the acceleration due to gravity. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        atmosphericPressure
            None or a Float specifying the atmospheric pressure. The default value is None.This
            argument is valid only when **definition** = SPHERICAL and **propagationModel** = UNDEX_CHARGE.
        dragCoefficient
            None or a Float specifying the fluid drag coefficient. The default value is None.This
            argument is valid only when **definition** = SPHERICAL and **propagationModel** = UNDEX_CHARGE.
        dragExponent
            A Float specifying the fluid drag exponent. The default value is 2.0.This argument is
            valid only when **definition** = SPHERICAL and **propagationModel** = UNDEX_CHARGE.
        waveEffects
            A Boolean specifying whether or not to include wave effects in the fluid and gas. The
            default value is ON.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        chargeDensity
            None or a Float specifying the density of the charge material. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        chargeMass
            None or a Float specifying the mass of the charge material. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        constantK1
            None or a Float specifying the charge material constant K. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        constantK2
            None or a Float specifying the charge material constant k. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        constantA
            None or a Float specifying the charge material constant A. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        constantB
            None or a Float specifying the charge material constant B. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        constantKc
            None or a Float specifying the charge material constant Kc. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        duration
            None or a Float specifying the time duration for the bubble simulation. The default
            value is None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        maximumSteps
            An Int specifying the maximum number of time steps for the bubble simulation. The
            default value is 1500.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        relativeStepControl
            A Float specifying the relative step size control parameter. The default value is
            1x10-11.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        absoluteStepControl
            A Float specifying the absolute step size control parameter. The default value is
            1x10-11.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        stepControlExponent
            A Float specifying the step size control exponent. The default value is 0.2.This
            argument is valid only when **definition** = SPHERICAL and **propagationModel** = UNDEX_CHARGE.
        genDecayA
            A Float specifying the constant A associated with the generalized decay propagation
            model. The default value is 0.0.This argument is valid only when **definition** = SPHERICAL
            and **propagationModel** = GENERALIZED_DECAY.
        genDecayB
            A Float specifying the constant B associated with the generalized decay propagation
            model. The default value is 0.0.This argument is valid only when **definition** = SPHERICAL
            and **propagationModel** = GENERALIZED_DECAY.
        genDecayC
            A Float specifying the constant C associated with the generalized decay propagation
            model. The default value is 0.0.This argument is valid only when **definition** = SPHERICAL
            and **propagationModel** = GENERALIZED_DECAY.
        seedNumber
            An Int specifying the seed number (N) for the diffuse source calculation. N2 sources
            will be used in the simulation.This argument is valid only when **definition** = DIFFUSE.
        massTNT
            A Float specifying the equivalent mass of TNT, in any preferred mass unit.This argument
            is valid only when **definition** = AIR_BLAST or **definition** = SURFACE_BLAST.
        massFactor
            A Float specifying the multiplication factor to convert from the preferred mass unit to
            kilograms. The default value is 1.0.This argument is valid only when
            **definition** = AIR_BLAST or **definition** = SURFACE_BLAST.
        lengthFactor
            A Float specifying the multiplication factor to convert from the analysis length unit to
            meters. The default value is 1.0.This argument is valid only when **definition** = AIR_BLAST
            or **definition** = SURFACE_BLAST.
        timeFactor
            A Float specifying the multiplication factor to convert from the analysis time unit to
            seconds. The default value is 1.0.This argument is valid only when
            **definition** = AIR_BLAST or **definition** = SURFACE_BLAST.
        pressureFactor
            A Float specifying the multiplication factor to convert from the analysis pressure unit
            to pascals. The default value is 1.0.This argument is valid only when
            **definition** = AIR_BLAST or **definition** = SURFACE_BLAST.

        Returns
        -------
        IncidentWaveProperty
            An :py:class:`~abaqus.Interaction.IncidentWaveProperty.IncidentWaveProperty` object.
        """
        super().__init__(name)
        pass

    def setValues(
        self,
        definition: SymbolicConstant = PLANAR,
        propagationModel: SymbolicConstant = ACOUSTIC,
        soundSpeed: float = None,
        fluidDensity: float = None,
        specificHeatRatio: float = None,
        gravity: float = None,
        atmosphericPressure: float = None,
        dragCoefficient: float = None,
        dragExponent: float = 2,
        waveEffects: Boolean = ON,
        chargeDensity: float = None,
        chargeMass: float = None,
        constantK1: float = None,
        constantK2: float = None,
        constantA: float = None,
        constantB: float = None,
        constantKc: float = None,
        duration: float = None,
        maximumSteps: int = 1500,
        relativeStepControl: float = None,
        absoluteStepControl: float = None,
        stepControlExponent: float = 0,
        genDecayA: float = 0,
        genDecayB: float = 0,
        genDecayC: float = 0,
        seedNumber: int = None,
        massTNT: float = None,
        massFactor: float = 1,
        lengthFactor: float = 1,
        timeFactor: float = 1,
        pressureFactor: float = 1,
    ):
        """This method modifies the IncidentWaveProperty object.

        Parameters
        ----------
        definition
            A SymbolicConstant specifying the type of wave to be defined. Possible values are
            PLANAR, SPHERICAL, DIFFUSE, AIR_BLAST, and SURFACE_BLAST. The default value is PLANAR.
        propagationModel
            A SymbolicConstant specifying the spherical propagation model. Possible values are
            ACOUSTIC, UNDEX_CHARGE, and GENERALIZED_DECAY. The default value is ACOUSTIC.This
            argument is valid only when **definition** = SPHERICAL.
        soundSpeed
            A Float specifying the speed of sound in the fluid.This argument is not valid when
            **definition** = AIR_BLAST or when **definition** = SURFACE_BLAST.
        fluidDensity
            A Float specifying the fluid mass density.This argument is not valid when
            **definition** = AIR_BLAST or when **definition** = SURFACE_BLAST.
        specificHeatRatio
            None or a Float specifying the ratio of specific heats for gas. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        gravity
            None or a Float specifying the acceleration due to gravity. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        atmosphericPressure
            None or a Float specifying the atmospheric pressure. The default value is None.This
            argument is valid only when **definition** = SPHERICAL and **propagationModel** = UNDEX_CHARGE.
        dragCoefficient
            None or a Float specifying the fluid drag coefficient. The default value is None.This
            argument is valid only when **definition** = SPHERICAL and **propagationModel** = UNDEX_CHARGE.
        dragExponent
            A Float specifying the fluid drag exponent. The default value is 2.0.This argument is
            valid only when **definition** = SPHERICAL and **propagationModel** = UNDEX_CHARGE.
        waveEffects
            A Boolean specifying whether or not to include wave effects in the fluid and gas. The
            default value is ON.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        chargeDensity
            None or a Float specifying the density of the charge material. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        chargeMass
            None or a Float specifying the mass of the charge material. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        constantK1
            None or a Float specifying the charge material constant K. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        constantK2
            None or a Float specifying the charge material constant k. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        constantA
            None or a Float specifying the charge material constant A. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        constantB
            None or a Float specifying the charge material constant B. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        constantKc
            None or a Float specifying the charge material constant Kc. The default value is
            None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        duration
            None or a Float specifying the time duration for the bubble simulation. The default
            value is None.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        maximumSteps
            An Int specifying the maximum number of time steps for the bubble simulation. The
            default value is 1500.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        relativeStepControl
            A Float specifying the relative step size control parameter. The default value is
            1x10-11.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        absoluteStepControl
            A Float specifying the absolute step size control parameter. The default value is
            1x10-11.This argument is valid only when **definition** = SPHERICAL and
            **propagationModel** = UNDEX_CHARGE.
        stepControlExponent
            A Float specifying the step size control exponent. The default value is 0.2.This
            argument is valid only when **definition** = SPHERICAL and **propagationModel** = UNDEX_CHARGE.
        genDecayA
            A Float specifying the constant A associated with the generalized decay propagation
            model. The default value is 0.0.This argument is valid only when **definition** = SPHERICAL
            and **propagationModel** = GENERALIZED_DECAY.
        genDecayB
            A Float specifying the constant B associated with the generalized decay propagation
            model. The default value is 0.0.This argument is valid only when **definition** = SPHERICAL
            and **propagationModel** = GENERALIZED_DECAY.
        genDecayC
            A Float specifying the constant C associated with the generalized decay propagation
            model. The default value is 0.0.This argument is valid only when **definition** = SPHERICAL
            and **propagationModel** = GENERALIZED_DECAY.
        seedNumber
            An Int specifying the seed number (N) for the diffuse source calculation. N2 sources
            will be used in the simulation.This argument is valid only when **definition** = DIFFUSE.
        massTNT
            A Float specifying the equivalent mass of TNT, in any preferred mass unit.This argument
            is valid only when **definition** = AIR_BLAST or **definition** = SURFACE_BLAST.
        massFactor
            A Float specifying the multiplication factor to convert from the preferred mass unit to
            kilograms. The default value is 1.0.This argument is valid only when
            **definition** = AIR_BLAST or **definition** = SURFACE_BLAST.
        lengthFactor
            A Float specifying the multiplication factor to convert from the analysis length unit to
            meters. The default value is 1.0.This argument is valid only when **definition** = AIR_BLAST
            or **definition** = SURFACE_BLAST.
        timeFactor
            A Float specifying the multiplication factor to convert from the analysis time unit to
            seconds. The default value is 1.0.This argument is valid only when
            **definition** = AIR_BLAST or **definition** = SURFACE_BLAST.
        pressureFactor
            A Float specifying the multiplication factor to convert from the analysis pressure unit
            to pascals. The default value is 1.0.This argument is valid only when
            **definition** = AIR_BLAST or **definition** = SURFACE_BLAST.
        """
        pass



import typing

from abaqusConstants import *
from .Fastener import Fastener
from ..Region.Region import Region


class DiscreteFastener(Fastener):
    """The DiscreteFastener object defines a discrete fastener.
    The DiscreteFastener object is derived from the Fastener object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import part
            mdb.models[name].parts[name].engineeringFeatures.fasteners[name]
            import assembly
            mdb.models[name].rootAssembly.engineeringFeatures.fasteners[name]

        The corresponding analysis keywords are:

        - COUPLING
    """

    #: A Boolean specifying whether the fastener is suppressed or not. The default value is
    #: OFF.
    suppressed: Boolean = OFF

    #: A String specifying the repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the fastener is applied.
    region: Region

    #: The SymbolicConstant WHOLE_SURFACE or a Float specifying the coupling influence radius.
    influenceRadius: typing.Union[SymbolicConstant, float]

    #: A Boolean specifying whether to constrain rotational displacement component about the
    #: 1-direction. The default value is ON.
    ur1: Boolean = ON

    #: A Boolean specifying whether to constrain rotational displacement component about the
    #: 2-direction. The default value is ON.
    ur2: Boolean = ON

    #: A Boolean specifying whether to constrain rotational displacement component about the
    #: 3-direction. The default value is ON.
    ur3: Boolean = ON

    #: A SymbolicConstant specifying the coupling method used to couple the displacement and
    #: rotation of each attachment point to the average motion of the surface nodes within the
    #: radius of influence from the fastening point. Possible values are CONTINUUM and
    #: STRUCTURAL. The default value is CONTINUUM.
    coupling: SymbolicConstant = CONTINUUM

    #: A SymbolicConstant specifying the weighting scheme to be used to weight the contribution
    #: of the displacements of the surface nodes within the radius of influence to the motion
    #: of the fastening point. UNIFORM, LINEAR, QUADRATIC, and CUBIC indicate uniform, linear
    #: decreasing, quadratic polynomial decreasing, and cubic polynomial monotonic decreasing
    #: weight distributions. Possible values are UNIFORM, LINEAR, QUADRATIC, and CUBIC. The
    #: default value is UNIFORM.
    weightingMethod: SymbolicConstant = UNIFORM

    #: None or a DatumCsys object specifying the local coordinate system of fastener couplings.
    #: If **localCsys** = None, couplings are defined in the global coordinate system. When this
    #: member is queried, it returns an Int. The default value is None.
    localCsys: int = None

    def __init__(
        self,
        name: str,
        region: Region,
        influenceRadius: typing.Union[SymbolicConstant, float],
        ur1: Boolean = ON,
        ur2: Boolean = ON,
        ur3: Boolean = ON,
        coupling: SymbolicConstant = CONTINUUM,
        weightingMethod: SymbolicConstant = UNIFORM,
        localCsys: int = None,
    ):
        """This method creates a DiscreteFastener object. Although the constructor is available
        both for parts and for the assembly, DiscreteFastener objects are currently supported
        only under the assembly.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].parts[name].engineeringFeatures.DiscreteFastener
                mdb.models[name].rootAssembly.engineeringFeatures.DiscreteFastener

        Parameters
        ----------
        name
            A String specifying the repository key.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the fastener is applied.
        influenceRadius
            The SymbolicConstant WHOLE_SURFACE or a Float specifying the coupling influence radius.
        ur1
            A Boolean specifying whether to constrain rotational displacement component about the
            1-direction. The default value is ON.
        ur2
            A Boolean specifying whether to constrain rotational displacement component about the
            2-direction. The default value is ON.
        ur3
            A Boolean specifying whether to constrain rotational displacement component about the
            3-direction. The default value is ON.
        coupling
            A SymbolicConstant specifying the coupling method used to couple the displacement and
            rotation of each attachment point to the average motion of the surface nodes within the
            radius of influence from the fastening point. Possible values are CONTINUUM and
            STRUCTURAL. The default value is CONTINUUM.
        weightingMethod
            A SymbolicConstant specifying the weighting scheme to be used to weight the contribution
            of the displacements of the surface nodes within the radius of influence to the motion
            of the fastening point. UNIFORM, LINEAR, QUADRATIC, and CUBIC indicate uniform, linear
            decreasing, quadratic polynomial decreasing, and cubic polynomial monotonic decreasing
            weight distributions. Possible values are UNIFORM, LINEAR, QUADRATIC, and CUBIC. The
            default value is UNIFORM.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of fastener couplings.
            If **localCsys** = None, couplings are defined in the global coordinate system. When this
            member is queried, it returns an Int. The default value is None.

        Returns
        -------
        DiscreteFastener
            A :py:class:`~abaqus.EngineeringFeature.DiscreteFastener.DiscreteFastener` object.
        """
        super().__init__()
        pass

    def setValues(
        self,
        ur1: Boolean = ON,
        ur2: Boolean = ON,
        ur3: Boolean = ON,
        coupling: SymbolicConstant = CONTINUUM,
        weightingMethod: SymbolicConstant = UNIFORM,
        localCsys: int = None,
    ):
        """This method modifies the DiscreteFastener object.

        Parameters
        ----------
        ur1
            A Boolean specifying whether to constrain rotational displacement component about the
            1-direction. The default value is ON.
        ur2
            A Boolean specifying whether to constrain rotational displacement component about the
            2-direction. The default value is ON.
        ur3
            A Boolean specifying whether to constrain rotational displacement component about the
            3-direction. The default value is ON.
        coupling
            A SymbolicConstant specifying the coupling method used to couple the displacement and
            rotation of each attachment point to the average motion of the surface nodes within the
            radius of influence from the fastening point. Possible values are CONTINUUM and
            STRUCTURAL. The default value is CONTINUUM.
        weightingMethod
            A SymbolicConstant specifying the weighting scheme to be used to weight the contribution
            of the displacements of the surface nodes within the radius of influence to the motion
            of the fastening point. UNIFORM, LINEAR, QUADRATIC, and CUBIC indicate uniform, linear
            decreasing, quadratic polynomial decreasing, and cubic polynomial monotonic decreasing
            weight distributions. Possible values are UNIFORM, LINEAR, QUADRATIC, and CUBIC. The
            default value is UNIFORM.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of fastener couplings.
            If **localCsys** = None, couplings are defined in the global coordinate system. When this
            member is queried, it returns an Int. The default value is None.
        """
        pass



from abaqusConstants import *
from .Constraint import Constraint
from ..Region.Region import Region


class AdjustPoints(Constraint):
    """The AdjustPoints constraint object is used to adjust points (nodes) to a surface.
    The AdjustPoints object is derived from the ConstrainedSketchConstraint object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].constraints[name]

        The corresponding analysis keywords are:

        - ADJUST
    """

    #: A Boolean specifying whether the constraint is suppressed or not. The default value is
    #: OFF.
    suppressed: Boolean = OFF

    #: A String specifying the constraint repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the surface to which the **controlPoints** are adjusted.
    surface: Region

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the constraint control points.
    controlPoints: Region

    def __init__(self, name: str, surface: Region, controlPoints: Region):
        """This method creates an AdjustPoints object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].AdjustPoints

        Parameters
        ----------
        name
            A String specifying the constraint repository key.
        surface
            A :py:class:`~abaqus.Region.Region.Region` object specifying the surface to which the **controlPoints** are adjusted.
        controlPoints
            A :py:class:`~abaqus.Region.Region.Region` object specifying the constraint control points.

        Returns
        -------
        AdjustPoints
            An :py:class:`~abaqus.Constraint.AdjustPoints.AdjustPoints` object.
        """
        super().__init__()
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the AdjustPoints object."""
        pass



from .Profile import Profile


class GeneralizedProfile(Profile):
    """The GeneralizedProfile object defines the properties of a profile via its area, moment
    of inertia, etc.
    The GeneralizedProfile object is derived from the Profile object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].profiles[name]
            import odbSection
            session.odbs[name].profiles[name]

        The corresponding analysis keywords are:

        - BEAM GENERAL SECTION
    """

    #: A String specifying the repository key.
    name: str

    #: A Float specifying the cross-sectional area for the profile.
    area: float

    #: A Float specifying the moment of inertia for bending about the 1-axis, I11I11.
    i11: float

    #: A Float specifying the moment of inertia for cross bending, I12I12.
    i12: float

    #: A Float specifying the moment of inertia for bending about the 2-axis, I22I22.
    i22: float

    #: A Float specifying the torsional constant, JJ.
    j: float

    #: A Float specifying the sectorial moment, Γ0Γ0.
    gammaO: float

    #: A Float specifying the warping constant, ΓWΓW.
    gammaW: float

    def __init__(
        self,
        name: str,
        area: float,
        i11: float,
        i12: float,
        i22: float,
        j: float,
        gammaO: float,
        gammaW: float,
    ):
        """This method creates a GeneralizedProfile object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].GeneralizedProfile
                session.odbs[name].GeneralizedProfile

        Parameters
        ----------
        name
            A String specifying the repository key.
        area
            A Float specifying the cross-sectional area for the profile.
        i11
            A Float specifying the moment of inertia for bending about the 1-axis, I11I11.
        i12
            A Float specifying the moment of inertia for cross bending, I12I12.
        i22
            A Float specifying the moment of inertia for bending about the 2-axis, I22I22.
        j
            A Float specifying the torsional constant, JJ.
        gammaO
            A Float specifying the sectorial moment, Γ0Γ0.
        gammaW
            A Float specifying the warping constant, ΓWΓW.

        Returns
        -------
        GeneralizedProfile
            A :py:class:`~abaqus.BeamSectionProfile.GeneralizedProfile.GeneralizedProfile` object.

        Raises
        ------
        RangeError

        """
        super().__init__()
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the GeneralizedProfile object.

        Raises
        ------
        RangeError

        """
        pass



from .RayleighDampingByFrequencyComponent import RayleighDampingByFrequencyComponent


class RayleighDampingByFrequencyComponentArray(
    list[RayleighDampingByFrequencyComponent]
):
    def findAt(self):
        pass



class ActivateElements:
    """The ActivateElements object is used turn on progressive element activation within a step
    definition.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            mdb.models[name].steps[name].activateElements[key]

        The corresponding analysis keywords are:

        - ActivateElements
                - ElementProgressiveActivation
    """

    #: A String specifying the name of the tableCollection object.
    tableCollection: str

    #: A string specifying the name of progressive element activation.
    activation: str

    #: A Double specifying the time constant used to ramp up the eigenstrains at element
    #: activation.
    eigenTimeConst: str = ""

    #: A Double specifying the time constant used to ramp up the thermal strains at element
    #: activation.
    expansionTimeConstant: str = ""

    def __init__(
        self,
        tableCollection: str,
        activation: str,
        eigenTimeConst: str = "",
        expansionTimeConstant: str = "",
    ):
        """This method creates an ActivateElements object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].ActivateElements

        Parameters
        ----------
        tableCollection
            A String specifying the name of the tableCollection object.
        activation
            A string specifying the name of progressive element activation.
        eigenTimeConst
            A Double specifying the time constant used to ramp up the eigenstrains at element
            activation.
        expansionTimeConstant
            A Double specifying the time constant used to ramp up the thermal strains at element
            activation.

        Returns
        -------
        ActivateElements
            An :py:class:`~abaqus.TableCollection.ActivateElements.ActivateElements` object.

        Raises
        ------
        RangeError
        """
        pass

    def setValues(self, *args, **kwargs):
        """This method modifies the ActivateElements object.

        Returns
        -------

        Raises
        ------
        RangeError
        """
        pass



import typing

from abaqusConstants import *
from .OdbAssembly import OdbAssembly
from .OdbInstance import OdbInstance
from .OdbMeshElement import OdbMeshElement
from .OdbMeshNode import OdbMeshNode
from .OdbPart import OdbPart
from .OdbSet import OdbSet
from .SectionPoint import SectionPoint


class HistoryPoint:
    """The HistoryPoint object specifies the point at which history data will be collected. The
    HistoryPoint object is a temporary object used as an argument to the HistoryRegion
    method.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import odbAccess
            session.odbs[name].steps[name].historyRegions[name].point
    """

    #: An Int specifying the integration point. This argument is used to define a history
    #: output position of INTEGRATION_POINT or ELEMENT_FACE_INTEGRATION_POINT. The default
    #: value is 0.
    ipNumber: int = 0

    #: A SymbolicConstant specifying the element face. This argument is used to define a
    #: history output position of ELEMENT_FACE or ELEMENT_FACE_INTEGRATION_POINT. Possible
    #: values are:
    #: 
    #: - FACE_UNKOWN, specifying this value indicates that no value has been specified.
    #: - FACE1, specifying this value indicates that element face 1 has been specified.
    #: - FACE2, specifying this value indicates that element face 2 has been specified.
    #: - FACE3, specifying this value indicates that element face 3 has been specified.
    #: - FACE4, specifying this value indicates that element face 4 has been specified.
    #: - FACE5, specifying this value indicates that element face 5 has been specified.
    #: - FACE6, specifying this value indicates that element face 6 has been specified.
    #: - SIDE1, specifying this value indicates that element side 1 has been specified.
    #: - SIDE2, specifying this value indicates element side 2 has been specified.
    #: - END1, specifying this value indicates that element end 1 has been specified.
    #: - END2, specifying this value indicates that element end 2 has been specified.
    #: - END3, specifying this value indicates that element end 3 has been specified.
    #: The default value is FACE_UNKNOWN.
    face: SymbolicConstant = FACE_UNKNOWN

    #: A SymbolicConstant specifying the result position of the history point. Possible values
    #: are:
    #: 
    #: - NODAL, specifying the values calculated at the nodes.
    #: - ELEMENT_NODAL, specifying the values obtained by extrapolating results calculated at
    #: the integration points.
    #: - INTEGRATION_POINT, specifying the values calculated at the integration points.
    #: - ELEMENT_FACE, specifying the results obtained for surface variables such as cavity
    #: radiation that are defined for the surface facets of an element.
    #: - ELEMENT_FACE_INTEGRATION_POINT, specifying the results obtained for surface variables
    #: such as cavity radiation that are defined for the surface facets of an element when the
    #: surface facets have integration points.
    #: - WHOLE_ELEMENT, specifying the results obtained for whole element variables.
    #: - WHOLE_REGION, specifying the results for an entire region of the model.
    #: - WHOLE_PART_INSTANCE, specifying the results for an entire part instance of the model.
    #: - WHOLE_MODEL, specifying the results for the entire model.
    position: SymbolicConstant = None

    #: An :py:class:`~abaqus.Odb.OdbMeshElement.OdbMeshElement` object specifying the element for which the data are to be collected.
    element: OdbMeshElement = OdbMeshElement()

    #: A :py:class:`~abaqus.Odb.SectionPoint.SectionPoint` object.
    sectionPoint: SectionPoint = None

    #: An :py:class:`~abaqus.Odb.OdbSet.OdbSet` object specifying the region for which the data are to be collected.
    region: OdbSet = OdbSet("set", tuple[OdbMeshNode]())

    #: An :py:class:`~abaqus.Odb.OdbAssembly.OdbAssembly` object specifying the assembly for which the data are to be collected.
    assembly: OdbAssembly = OdbAssembly()

    #: An :py:class:`~abaqus.Odb.OdbInstance.OdbInstance` object specifying the instance for which the data are to be collected.
    instance: OdbInstance = OdbInstance(
        "instance", OdbPart("part", THREE_D, DEFORMABLE_BODY)
    )

    #: An :py:class:`~abaqus.Odb.OdbMeshNode.OdbMeshNode` object specifying the node for which the data are to be collected.
    node: OdbMeshNode

    def __init__(self, node: OdbMeshNode):
        """This method creates a HistoryPoint object for a node.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                odbAccess.HistoryPoint

        Parameters
        ----------
        node
            An :py:class:`~abaqus.Odb.OdbMeshNode.OdbMeshNode` object specifying the node for which the data are to be collected.

        Returns
        -------
        HistoryPoint
            A :py:class:`~abaqus.Odb.HistoryPoint.HistoryPoint` object.
        """
        pass

    def __init__(
        self,
        element: OdbMeshElement,
        ipNumber: int = 0,
        sectionPoint: SectionPoint = None,
        face: SymbolicConstant = FACE_UNKNOWN,
        node: OdbMeshNode = None, 
    ):
        """This method creates a HistoryPoint object for an element.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                odbAccess.HistoryPoint

        Parameters
        ----------
        element
            An :py:class:`~abaqus.Odb.OdbMeshElement.OdbMeshElement` object specifying the element for which the data are to be collected.
        ipNumber
            An Int specifying the integration point. This argument is used to define a history
            output position of INTEGRATION_POINT or ELEMENT_FACE_INTEGRATION_POINT. The default
            value is 0.
        sectionPoint
            A :py:class:`~abaqus.Odb.SectionPoint.SectionPoint` object.
        face
            A SymbolicConstant specifying the element face. This argument is used to define a
            history output position of ELEMENT_FACE or ELEMENT_FACE_INTEGRATION_POINT. Possible
            values are:
            
            - FACE_UNKOWN, specifying this value indicates that no value has been specified.
            - FACE1, specifying this value indicates that element face 1 has been specified.
            - FACE2, specifying this value indicates that element face 2 has been specified.
            - FACE3, specifying this value indicates that element face 3 has been specified.
            - FACE4, specifying this value indicates that element face 4 has been specified.
            - FACE5, specifying this value indicates that element face 5 has been specified.
            - FACE6, specifying this value indicates that element face 6 has been specified.
            - SIDE1, specifying this value indicates that element side 1 has been specified.
            - SIDE2, specifying this value indicates element side 2 has been specified.
            - END1, specifying this value indicates that element end 1 has been specified.
            - END2, specifying this value indicates that element end 2 has been specified.
            - END3, specifying this value indicates that element end 3 has been specified.
            
            The default value is FACE_UNKNOWN.
        node
            An :py:class:`~abaqus.Odb.OdbMeshNode.OdbMeshNode` object specifying the node for which the data are to be collected.

        Returns
        -------
        HistoryPoint
            A :py:class:`~abaqus.Odb.HistoryPoint.HistoryPoint` object.
        """
        pass

    def __init__(self, region: OdbSet):
        """This method creates a HistoryPoint object for a region.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                odbAccess.HistoryPoint

        Parameters
        ----------
        region
            An :py:class:`~abaqus.Odb.OdbSet.OdbSet` object specifying the region for which the data are to be collected.

        Returns
        -------
        HistoryPoint
            A :py:class:`~abaqus.Odb.HistoryPoint.HistoryPoint` object.
        """
        pass

    def __init__(self, assembly: OdbAssembly):
        """This method creates a HistoryPoint object for the OdbAssembly object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                odbAccess.HistoryPoint

        Parameters
        ----------
        assembly
            An :py:class:`~abaqus.Odb.OdbAssembly.OdbAssembly` object specifying the assembly for which the data are to be collected.

        Returns
        -------
        HistoryPoint
            A :py:class:`~abaqus.Odb.HistoryPoint.HistoryPoint` object.
        """
        pass

    def __init__(self, instance: OdbInstance):
        """This method creates a HistoryPoint object for the OdbInstance object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                odbAccess.HistoryPoint

        Parameters
        ----------
        instance
            An :py:class:`~abaqus.Odb.OdbInstance.OdbInstance` object specifying the instance for which the data are to be collected.

        Returns
        -------
        HistoryPoint
            A :py:class:`~abaqus.Odb.HistoryPoint.HistoryPoint` object.
        """
        pass

    def __init__(self, *args, **kwargs):
        pass



from .StructuralDampingComponentArray import StructuralDampingComponentArray


class StructuralDamping:
    """A :py:class:`~abaqus.StepMiscellaneous.StructuralDamping.StructuralDamping` object contains structural damping parameters.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name].structuralDamping
    """

    #: A :py:class:`~abaqus.StepMiscellaneous.StructuralDampingComponentArray.StructuralDampingComponentArray` object.
    components: StructuralDampingComponentArray = StructuralDampingComponentArray()
